# -*- coding: utf-8 -*-


class PayoutStatus:
    """
    Статус выплаты.
    """  # noqa: E501

    """
    Список допустимых значений
    """
    PENDING = 'pending'
    """Только для выплат на банковские карты: выплата создана и ожидает подтверждения от эмитента, что деньги можно перевести на указанную банковскую карту."""
    SUCCEEDED = 'succeeded'
    """Выплата успешно завершена, оплата переведена на платежное средство продавца (финальный и неизменяемый статус)."""
    CANCELED = 'canceled'
    """Выплата отменена, инициатор и причина отмены указаны в объекте cancellation_details (финальный и неизменяемый статус)."""



# -*- coding: utf-8 -*-
from yookassa.domain.common import ResponseObject, PaymentMethodType
from yookassa.domain.models import Amount, AuthorizationDetails, CancellationDetails, Recipient
from yookassa.domain.models.confirmation.confirmation_factory import ConfirmationFactory
from yookassa.domain.models.deal import PaymentDealInfo
from yookassa.domain.models.payment_data.payment_data_class_map import PaymentDataClassMap
from yookassa.domain.models.payment_data.payment_data_factory import PaymentDataFactory
from yookassa.domain.models.payment_data.payment_invoice_details import PaymentInvoiceDetails
from yookassa.domain.response.transfer_response import TransferResponse


class PaymentResponse(ResponseObject):
    """
    Объект ответа, возвращаемого API при запросе конкретного платежа.
    """  # noqa: E501

    __id = None
    """Идентификатор платежа в ЮKassa."""  # noqa: E501

    __status = None
    """Текущее состояние платежа."""  # noqa: E501

    __amount = None
    """Сумма заказа."""  # noqa: E501

    __income_amount = None
    """Сумма платежа, которую получит магазин."""  # noqa: E501

    __description = None
    """Описание транзакции (не более 128 символов), которое вы увидите в личном кабинете ЮKassa, а пользователь — при оплате. Например: «Оплата заказа № 72 для user@yoomoney.ru». """  # noqa: E501

    __recipient = None
    """Получатель платежа."""  # noqa: E501

    __payment_method = None
    """Способ проведения платежа."""  # noqa: E501

    __captured_at = None
    """Время подтверждения платежа. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). """  # noqa: E501

    __created_at = None
    """Время создания заказа. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    __expires_at = None
    """Время, до которого вы можете бесплатно отменить или подтвердить платеж. В указанное время платеж в статусе ~`waiting_for_capture` будет автоматически отменен. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    __confirmation = None
    """Выбранный способ подтверждения платежа. """  # noqa: E501

    __test = None
    """Признак тестовой операции."""  # noqa: E501

    __refunded_amount = None
    """Сумма возвращенных средств платежа."""  # noqa: E501

    __paid = None
    """Признак оплаты заказа."""  # noqa: E501

    __refundable = None
    """Возможность провести возврат по API."""  # noqa: E501

    __receipt_registration = None
    """Состояние регистрации фискального чека"""  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    __cancellation_details = None
    """Комментарий к отмене платежа."""  # noqa: E501

    __authorization_details = None
    """Данные об авторизации платежа."""  # noqa: E501

    __transfers = None
    """Данные о распределении денег — сколько и в какой магазин нужно перевести. Присутствует, если вы используете %[Сплитование платежей](/developers/solutions-for-platforms/split-PaymentResponses/basics)."""  # noqa: E501

    __deal = None
    """Данные о сделке, в составе которой проходит платеж."""  # noqa: E501

    __merchant_customer_id = None
    """Идентификатор покупателя в вашей системе, например электронная почта или номер телефона."""  # noqa: E501

    __invoice_details = None
    """Данные о выставленном счете, в рамках которого проведен платеж"""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели PaymentResponse.

        :return: id модели PaymentResponse.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели PaymentResponse.

        :param value: id модели PaymentResponse.
        :type value: str
        """
        self.__id = value

    @property
    def status(self):
        """
        Возвращает status модели PaymentResponse.

        :return: status модели PaymentResponse.
        :rtype: str
        """
        return self.__status

    @status.setter
    def status(self, value):
        """
        Устанавливает status модели PaymentResponse.

        :param value: status модели PaymentResponse.
        :type value: str
        """
        self.__status = value

    @property
    def amount(self):
        """
        Возвращает amount модели PaymentResponse.

        :return: amount модели PaymentResponse.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели PaymentResponse.

        :param value: amount модели PaymentResponse.
        :type value: Amount
        """
        self.__amount = Amount(value)

    @property
    def income_amount(self):
        """
        Возвращает income_amount модели PaymentResponse.

        :return: income_amount модели PaymentResponse.
        :rtype: Amount
        """
        return self.__income_amount

    @income_amount.setter
    def income_amount(self, value):
        """
        Устанавливает income_amount модели PaymentResponse.

        :param value: income_amount модели PaymentResponse.
        :type value: Amount
        """
        self.__income_amount = Amount(value)

    @property
    def description(self):
        """
        Возвращает description модели PaymentResponse.

        :return: description модели PaymentResponse.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели PaymentResponse.

        :param value: description модели PaymentResponse.
        :type value: str
        """
        self.__description = value

    @property
    def recipient(self):
        """
        Возвращает recipient модели PaymentResponse.

        :return: recipient модели PaymentResponse.
        :rtype: Recipient
        """
        return self.__recipient

    @recipient.setter
    def recipient(self, value):
        """
        Устанавливает recipient модели PaymentResponse.

        :param value: recipient модели PaymentResponse.
        :type value: Recipient
        """
        self.__recipient = Recipient(value)

    @property
    def payment_method(self):
        """
        Возвращает payment_method модели PaymentResponse.

        :return: payment_method модели PaymentResponse.
        :rtype: PaymentPaymentMethod
        """
        return self.__payment_method

    @payment_method.setter
    def payment_method(self, value):
        """
        Устанавливает payment_method модели PaymentResponse.

        :param value: payment_method модели PaymentResponse.
        :type value: PaymentData
        """
        if isinstance(value, dict) and 'type' in value and value['type'] not in PaymentDataClassMap().response:
            value['type'] = PaymentMethodType.UNKNOWN
        self.__payment_method = PaymentDataFactory().create(value, self.context())

    @property
    def captured_at(self):
        """
        Возвращает captured_at модели PaymentResponse.

        :return: captured_at модели PaymentResponse.
        :rtype: datetime
        """
        return self.__captured_at

    @captured_at.setter
    def captured_at(self, value):
        """
        Устанавливает captured_at модели PaymentResponse.

        :param value: captured_at модели PaymentResponse.
        :type value: datetime
        """
        self.__captured_at = value

    @property
    def created_at(self):
        """
        Возвращает created_at модели PaymentResponse.

        :return: created_at модели PaymentResponse.
        :rtype: datetime
        """
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        """
        Устанавливает created_at модели PaymentResponse.

        :param value: created_at модели PaymentResponse.
        :type value: datetime
        """
        self.__created_at = value

    @property
    def expires_at(self):
        """
        Возвращает expires_at модели PaymentResponse.

        :return: expires_at модели PaymentResponse.
        :rtype: datetime
        """
        return self.__expires_at

    @expires_at.setter
    def expires_at(self, value):
        """
        Устанавливает expires_at модели PaymentResponse.

        :param value: expires_at модели PaymentResponse.
        :type value: datetime
        """
        self.__expires_at = value

    @property
    def confirmation(self):
        """
        Возвращает confirmation модели PaymentResponse.

        :return: confirmation модели PaymentResponse.
        :rtype: ConfirmationRequest
        """
        return self.__confirmation

    @confirmation.setter
    def confirmation(self, value):
        """
        Устанавливает confirmation модели PaymentResponse.

        :param value: confirmation модели PaymentResponse.
        :type value: ConfirmationRequest
        """
        self.__confirmation = ConfirmationFactory().create(value, self.context())

    @property
    def test(self):
        """
        Возвращает test модели PaymentResponse.

        :return: test модели PaymentResponse.
        :rtype: bool
        """
        return self.__test

    @test.setter
    def test(self, value):
        """
        Устанавливает test модели PaymentResponse.

        :param value: test модели PaymentResponse.
        :type value: bool
        """
        self.__test = bool(value)

    @property
    def refunded_amount(self):
        """
        Возвращает refunded_amount модели PaymentResponse.

        :return: refunded_amount модели PaymentResponse.
        :rtype: Amount
        """
        return self.__refunded_amount

    @refunded_amount.setter
    def refunded_amount(self, value):
        """
        Устанавливает refunded_amount модели PaymentResponse.

        :param value: refunded_amount модели PaymentResponse.
        :type value: Amount
        """
        self.__refunded_amount = Amount(value)

    @property
    def paid(self):
        """
        Возвращает paid модели PaymentResponse.

        :return: paid модели PaymentResponse.
        :rtype: bool
        """
        return self.__paid

    @paid.setter
    def paid(self, value):
        """
        Устанавливает paid модели PaymentResponse.

        :param value: paid модели PaymentResponse.
        :type value: bool
        """
        self.__paid = bool(value)

    @property
    def refundable(self):
        """
        Возвращает refundable модели PaymentResponse.

        :return: refundable модели PaymentResponse.
        :rtype: bool
        """
        return self.__refundable

    @refundable.setter
    def refundable(self, value):
        """
        Устанавливает refundable модели PaymentResponse.

        :param value: refundable модели PaymentResponse.
        :type value: bool
        """
        self.__refundable = bool(value)

    @property
    def receipt_registration(self):
        """
        Возвращает receipt_registration модели PaymentResponse.

        :return: receipt_registration модели PaymentResponse.
        :rtype: str
        """
        return self.__receipt_registration

    @receipt_registration.setter
    def receipt_registration(self, value):
        """
        Устанавливает receipt_registration модели PaymentResponse.

        :param value: receipt_registration модели PaymentResponse.
        :type value: str
        """
        self.__receipt_registration = value

    @property
    def metadata(self):
        """
        Возвращает metadata модели PaymentResponse.

        :return: metadata модели PaymentResponse.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели PaymentResponse.

        :param value: metadata модели PaymentResponse.
        :type value: dict[str, str]
        """
        self.__metadata = value

    @property
    def cancellation_details(self):
        """
        Возвращает cancellation_details модели PaymentResponse.

        :return: cancellation_details модели PaymentResponse.
        :rtype: CancellationDetails
        """
        return self.__cancellation_details

    @cancellation_details.setter
    def cancellation_details(self, value):
        """
        Устанавливает cancellation_details модели PaymentResponse.

        :param value: cancellation_details модели PaymentResponse.
        :type value: CancellationDetails
        """
        self.__cancellation_details = CancellationDetails(value)

    @property
    def authorization_details(self):
        """
        Возвращает authorization_details модели PaymentResponse.

        :return: authorization_details модели PaymentResponse.
        :rtype: AuthorizationDetails
        """
        return self.__authorization_details

    @authorization_details.setter
    def authorization_details(self, value):
        """
        Устанавливает authorization_details модели PaymentResponse.

        :param value: authorization_details модели PaymentResponse.
        :type value: AuthorizationDetails
        """
        self.__authorization_details = AuthorizationDetails(value)

    @property
    def transfers(self):
        """
        Возвращает transfers модели PaymentResponse.

        :return: transfers модели PaymentResponse.
        :rtype: list[TransferResponse]
        """
        return self.__transfers

    @transfers.setter
    def transfers(self, value):
        """
        Устанавливает transfers модели PaymentResponse.

        :param value: transfers модели PaymentResponse.
        :type value: list[TransferResponse]
        """
        if isinstance(value, list):
            self.__transfers = [TransferResponse(item) for item in value]
        elif value is None:
            self.__transfers = value
        else:
            raise TypeError('Invalid transfers data type in payment_response.transfers')

    @property
    def deal(self):
        """
        Возвращает deal модели PaymentResponse.

        :return: deal модели PaymentResponse.
        :rtype: PaymentDealInfo
        """
        return self.__deal

    @deal.setter
    def deal(self, value):
        """
        Устанавливает deal модели PaymentResponse.

        :param value: deal модели PaymentResponse.
        :type value: PaymentDealInfo
        """
        self.__deal = PaymentDealInfo(value)

    @property
    def merchant_customer_id(self):
        """
        Возвращает merchant_customer_id модели PaymentResponse.

        :return: merchant_customer_id модели PaymentResponse.
        :rtype: str
        """
        return self.__merchant_customer_id

    @merchant_customer_id.setter
    def merchant_customer_id(self, value):
        """
        Устанавливает merchant_customer_id модели PaymentResponse.

        :param value: merchant_customer_id модели PaymentResponse.
        :type value: str
        """
        self.__merchant_customer_id = value

    @property
    def invoice_details(self):
        """Возвращает invoice_details модели Payment.

        :return: invoice_details модели Payment.
        :rtype: PaymentInvoiceDetails
        """
        return self.__invoice_details

    @invoice_details.setter
    def invoice_details(self, value):
        """Устанавливает invoice_details модели Payment.

        :param value: invoice_details модели Payment.
        :type value: PaymentInvoiceDetails
        """
        self.__invoice_details = PaymentInvoiceDetails(value)



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject
from yookassa.domain.models import Amount


class ElectronicCertificateArticle(BaseObject):
    """Товарная позиция в корзине покупки при оплате по электронному сертификату."""  # noqa: E501

    __article_number = None
    """Порядковый номер товара в корзине. От 1 до 999 включительно. """  # noqa: E501

    __tru_code = None
    """Код ТРУ. 30 символов, две группы цифр, разделенные точкой. Формат: ~`NNNNNNNNN.NNNNNNNNNYYYYMMMMZZZ`, где ~`NNNNNNNNN.NNNNNNNNN` — код вида ТРУ по [Перечню ТРУ](https://esnsi.gosuslugi.ru/classifiers/10616/data?pg=1&p=1), ~`YYYY` — код производителя, ~`MMMM` — код модели, ~`ZZZ` — код страны производителя. Пример: ~`329921120.06001010200080001643`  [Как сформировать код ТРУ](/developers/payment-acceptance/integration-scenarios/manual-integration/other/electronic-certificate/basics#payments-preparations-tru-code) """  # noqa: E501

    __article_code = None
    """Код товара в вашей системе. Максимум 128 символов. """  # noqa: E501

    __article_name = None
    """Название товара в вашей системе. Отображается на готовой платежной форме ЮKassa. Максимум 128 символов. """  # noqa: E501

    __quantity = None
    """Количество единиц товара. Формат: целое положительное число. """  # noqa: E501

    __price = None
    """Цена за единицу товара."""

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    @property
    def article_number(self):
        """Возвращает article_number модели ElectronicCertificateArticle.

        :return: article_number модели ElectronicCertificateArticle.
        :rtype: int
        """
        return self.__article_number

    @article_number.setter
    def article_number(self, value):
        """Устанавливает article_number модели ElectronicCertificateArticle.

        :param value: article_number модели ElectronicCertificateArticle.
        :type value: int
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `article_number`, must not be `None`")  # noqa: E501
        if value is not None and value > 999:  # noqa: E501
            raise ValueError("Invalid value for `article_number`, must be a value less than or equal to `999`")  # noqa: E501
        if value is not None and value < 1:  # noqa: E501
            raise ValueError("Invalid value for `article_number`, must be a value greater than or equal to `1`")  # noqa: E501
        self.__article_number = value

    @property
    def tru_code(self):
        """Возвращает tru_code модели ElectronicCertificateArticle.

        :return: tru_code модели ElectronicCertificateArticle.
        :rtype: str
        """
        return self.__tru_code

    @tru_code.setter
    def tru_code(self, value):
        """Устанавливает tru_code модели ElectronicCertificateArticle.

        :param value: tru_code модели ElectronicCertificateArticle.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `tru_code`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 30:
            raise ValueError("Invalid value for `tru_code`, length must be less than or equal to `30`")  # noqa: E501
        if value is not None and len(value) < 30:
            raise ValueError("Invalid value for `tru_code`, length must be greater than or equal to `30`")  # noqa: E501
        self.__tru_code = value

    @property
    def article_code(self):
        """Возвращает article_code модели ElectronicCertificateArticle.

        :return: article_code модели ElectronicCertificateArticle.
        :rtype: str
        """
        return self.__article_code

    @article_code.setter
    def article_code(self, value):
        """Устанавливает article_code модели ElectronicCertificateArticle.

        :param value: article_code модели ElectronicCertificateArticle.
        :type value: str
        """
        if value is not None and len(value) > 128:
            raise ValueError("Invalid value for `article_code`, length must be less than or equal to `128`")  # noqa: E501
        self.__article_code = value

    @property
    def article_name(self):
        """Возвращает article_name модели ElectronicCertificateArticle.

        :return: article_name модели ElectronicCertificateArticle.
        :rtype: str
        """
        return self.__article_name

    @article_name.setter
    def article_name(self, value):
        """Устанавливает article_name модели ElectronicCertificateArticle.

        :param value: article_name модели ElectronicCertificateArticle.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `article_name`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 128:
            raise ValueError("Invalid value for `article_name`, length must be less than or equal to `128`")  # noqa: E501
        self.__article_name = value

    @property
    def quantity(self):
        """Возвращает quantity модели ElectronicCertificateArticle.

        :return: quantity модели ElectronicCertificateArticle.
        :rtype: int
        """
        return self.__quantity

    @quantity.setter
    def quantity(self, value):
        """Устанавливает quantity модели ElectronicCertificateArticle.

        :param value: quantity модели ElectronicCertificateArticle.
        :type value: int
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must not be `None`")  # noqa: E501
        self.__quantity = value

    @property
    def price(self):
        """Возвращает price модели ElectronicCertificateArticle.

        :return: price модели ElectronicCertificateArticle.
        :rtype: ElectronicCertificateArticlePrice
        """
        return self.__price

    @price.setter
    def price(self, value):
        """Устанавливает price модели ElectronicCertificateArticle.

        :param value: price модели ElectronicCertificateArticle.
        :type value: ElectronicCertificateArticlePrice
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501
        if isinstance(value, dict):
            self.__price = Amount(value)
        elif isinstance(value, Amount):
            self.__price = value
        else:
            raise TypeError('Invalid price data type in ElectronicCertificateArticle.price')

    @property
    def metadata(self):
        """Возвращает metadata модели ElectronicCertificateArticle.

        :return: metadata модели ElectronicCertificateArticle.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """Устанавливает metadata модели ElectronicCertificateArticle.

        :param value: metadata модели ElectronicCertificateArticle.
        :type value: dict[str, str]
        """
        self.__metadata = value





# -*- coding: utf-8 -*-
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.models.invoice_data.delivery_method_class_map import DeliveryMethodClassMap


class DeliveryMethodFactory(TypeFactory):
    """
    Фабрика создания объекта PayoutDestination по типу.
    """  # noqa: E501

    def __init__(self):
        super(DeliveryMethodFactory, self).__init__(DeliveryMethodClassMap())



# -*- coding: utf-8 -*-
import copy
import logging


class Adapter(logging.LoggerAdapter):
    """
    Класс Adapter.
    """  # noqa: E501

    def __init__(self, logger, extra):
        super(Adapter, self).__init__(logger, extra)
        self.env = extra

    def process(self, msg, kwargs):
        """
        Процесс обработки сообщения для логирования
        :param msg: Сообщение
        :param kwargs: Словарь с дополнительными параметрами.
        """
        msg, kwargs = super(Adapter, self).process(msg, kwargs)

        result = copy.deepcopy(kwargs)

        default_kwargs_key = ['exc_info', 'stack_info', 'extra']
        custom_key = [k for k in result.keys() if k not in default_kwargs_key]
        result['extra'].update({k: result.pop(k) for k in custom_key})

        return msg, result



# coding: utf-8
from yookassa.domain.common import RequestObject
from yookassa.domain.models.confirmation.request.confirmation_request import ConfirmationRequest
from yookassa.domain.models.payment_data.request.credit_card import CreditCard
from yookassa.domain.models.payment_method.payment_method_confirmation_factory import PaymentMethodConfirmationFactory
from yookassa.domain.models.payment_method.request.payment_method_holder import PaymentMethodHolder


class PaymentMethodRequest(RequestObject):
    """Данные для проверки и сохранения способа оплаты."""  # noqa: E501

    __type = None
    """Код способа оплаты. Возможное значение: * ~`bank_card` — банковская карта."""  # noqa: E501

    __card = None
    """Данные банковской карты."""

    __holder = None
    """Данные магазина, для которого сохраняется способ оплаты."""

    __client_ip = None
    """IPv4 или IPv6-адрес пользователя. Если не указан, используется IP-адрес TCP-подключения."""  # noqa: E501

    __confirmation = None
    """Данные, необходимые для инициирования сценария подтверждения привязки."""  # noqa: E501

    @property
    def type(self):
        """Возвращает type модели PaymentMethodRequest.

        :return: type модели PaymentMethodRequest.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """Устанавливает type модели PaymentMethodRequest.

        :param value: type модели PaymentMethodRequest.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self.__type = str(value)

    @property
    def card(self):
        """Возвращает card модели PaymentMethodResponse.

        :return: card модели PaymentMethodResponse.
        :rtype: CreditCard
        """
        return self.__card

    @card.setter
    def card(self, value):
        """Устанавливает card модели PaymentMethodResponse.

        :param value: card модели PaymentMethodResponse.
        :type value: CreditCard
        """
        if isinstance(value, dict):
            self.__card = CreditCard(value)
        elif isinstance(value, CreditCard):
            self.__card = value
        else:
            raise TypeError('Invalid card value type')

    @property
    def holder(self):
        """Возвращает holder модели PaymentMethodRequest.

        :return: holder модели PaymentMethodRequest.
        :rtype: PaymentMethodHolder
        """
        return self.__holder

    @holder.setter
    def holder(self, value):
        """Устанавливает holder модели PaymentMethodRequest.

        :param value: holder модели PaymentMethodRequest.
        :type value: PaymentMethodHolder
        """
        if isinstance(value, dict):
            self.__holder = PaymentMethodHolder(value)
        elif isinstance(value, PaymentMethodHolder):
            self.__holder = value
        else:
            raise TypeError('Invalid holder value type')

    @property
    def client_ip(self):
        """Возвращает client_ip модели PaymentMethodRequest.

        :return: client_ip модели PaymentMethodRequest.
        :rtype: str
        """
        return self.__client_ip

    @client_ip.setter
    def client_ip(self, value):
        """Устанавливает client_ip модели PaymentMethodRequest.

        :param value: client_ip модели PaymentMethodRequest.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            self.__client_ip = cast_value

    @property
    def confirmation(self):
        """Возвращает confirmation модели PaymentMethodRequest.

        :return: confirmation модели PaymentMethodRequest.
        :rtype: ConfirmationRequest
        """
        return self.__confirmation

    @confirmation.setter
    def confirmation(self, value):
        """Устанавливает confirmation модели PaymentMethodRequest.

        :param value: confirmation модели PaymentMethodRequest.
        :type value: ConfirmationRequest
        """
        if isinstance(value, dict):
            self.__confirmation = PaymentMethodConfirmationFactory().create(value, self.context())
        elif isinstance(value, ConfirmationRequest):
            self.__confirmation = value
        else:
            raise TypeError('Invalid confirmation data type in PaymentMethodRequest.confirmation')

    def validate(self):
        """
        Валидация данных модели PaymentMethodRequest.
        """
        if not self.type:
            self.__set_validation_error('Payment method type not specified')

    def __set_validation_error(self, message):
        """
        Устанавливает message в Exception при валидации модели PaymentMethodRequest.

        :param message: message модели Exception.
        :type message: str
        """
        raise ValueError(message)



# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.request.payment_data_bank_card import PaymentDataBankCard


class PaymentDataTinkoffBank(PaymentDataBankCard):
    """
    Данные для оплаты через T-Pay.
    """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataTinkoffBank, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.TINKOFF_BANK:
            self.type = PaymentMethodType.TINKOFF_BANK



# coding: utf-8

from yookassa.domain.common import BaseObject
from yookassa.domain.models import Receipt, Amount, Recipient


class PaymentData(BaseObject):
    """Данные для проведения платежа по выставленному счету."""  # noqa: E501

    __amount = None
    """
    Сумма платежа. Должна укладываться в [лимиты](/docs/support/payments/limits). Сумма указывается с кодом валюты.
    Если вы разделяете потоки платежей, валюта платежа должна соответствовать валюте субаккаунта (`recipient.gateway_id`), если не разделяете — валюте аккаунта `shopId` в личном кабинете)
    """  # noqa: E501

    __receipt = None
    """
    Данные для формирования чека.
    Необходимо передавать в этих случаях:
    - вы компания или ИП и для оплаты с соблюдением требований 54-ФЗ используете [Чеки от ЮKassa](https://yookassa.ru/developers/payment-acceptance/receipts/54fz/yoomoney/basics);
    - вы компания или ИП, для оплаты с соблюдением требований 54-ФЗ используете [стороннюю онлайн-кассу](https://yookassa.ru/developers/payment-acceptance/receipts/54fz/other-services/basics) и отправляете данные для чеков по одному из сценариев: [Платеж и чек одновременно](https://yookassa.ru/developers/payment-acceptance/receipts/54fz/other-services/basics#payment-and-receipt) или [Сначала чек, потом платеж](https://yookassa.ru/developers/payment-acceptance/receipts/54fz/other-services/basics#payment-after-receipt);
    - вы самозанятый и используете решение ЮKassa для [автоотправки чеков](https://yookassa.ru/developers/payment-acceptance/receipts/self-employed/basics).
    """  # noqa: E501

    __recipient = None
    """"""  # noqa: E501

    __save_payment_method = None
    """Сохранение платежных данных для проведения [автоплатежей](https://yookassa.ru/developers/payment-acceptance/scenario-extensions/recurring-payments). Возможные значения:  * ~`true` — сохранить способ оплаты (сохранить платежные данные); * ~`false` — провести платеж без сохранения способа оплаты.  Доступно только после согласования с менеджером ЮKassa. """  # noqa: E501

    __capture = None
    """[Автоматический прием](https://yookassa.ru/developers/payment-acceptance/getting-started/payment-process#capture-true) поступившего платежа. Возможные значения:  * ~`true` — оплата списывается сразу (платеж в одну стадию); * ~`false` — оплата холдируется и списывается по вашему запросу ([платеж в две стадии](https://yookassa.ru/developers/payment-acceptance/getting-started/payment-process#capture-and-cancel)).  По умолчанию ~`false`. """  # noqa: E501

    __client_ip = None
    """IPv4 или IPv6-адрес пользователя. Если не указан, используется IP-адрес TCP-подключения."""  # noqa: E501

    __description = None
    """Описание транзакции (не более 128 символов), которое вы увидите в личном кабинете ЮKassa, а пользователь — при оплате. Например: «Оплата заказа № 72 для user@yoomoney.ru». """  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    @property
    def amount(self):
        """Возвращает amount модели PaymentData.

        :return: amount модели PaymentData.
        :rtype: PaymentDataAmount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """Устанавливает amount модели PaymentData.

        :param value: amount модели PaymentData.
        :type value: PaymentDataAmount
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount data type in PaymentData.amount')

    @property
    def receipt(self):
        """Возвращает receipt модели PaymentData.

        :return: receipt модели PaymentData.
        :rtype: ReceiptData
        """
        return self.__receipt

    @receipt.setter
    def receipt(self, value):
        """Устанавливает receipt модели PaymentData.

        :param value: receipt модели PaymentData.
        :type value: ReceiptData
        """
        if isinstance(value, dict):
            self.__receipt = Receipt(value)
        elif isinstance(value, Receipt):
            self.__receipt = value
        else:
            raise TypeError('Invalid receipt data type in PaymentData.receipt')

    @property
    def recipient(self):
        """Возвращает recipient модели PaymentData.

        :return: recipient модели PaymentData.
        :rtype: Recipient
        """
        return self.__recipient

    @recipient.setter
    def recipient(self, value):
        """Устанавливает recipient модели PaymentData.

        :param value: recipient модели PaymentData.
        :type value: Recipient
        """
        if isinstance(value, dict):
            self.__recipient = Recipient(value)
        elif isinstance(value, Recipient):
            self.__recipient = value
        else:
            raise TypeError('Invalid recipient data type in PaymentData.recipient')

    @property
    def save_payment_method(self):
        """Возвращает save_payment_method модели PaymentData.

        :return: save_payment_method модели PaymentData.
        :rtype: bool
        """
        return self.__save_payment_method

    @save_payment_method.setter
    def save_payment_method(self, value):
        """Устанавливает save_payment_method модели PaymentData.

        :param value: save_payment_method модели PaymentData.
        :type value: bool
        """
        self.__save_payment_method = value

    @property
    def capture(self):
        """Возвращает capture модели PaymentData.

        :return: capture модели PaymentData.
        :rtype: bool
        """
        return self.__capture

    @capture.setter
    def capture(self, value):
        """Устанавливает capture модели PaymentData.

        :param value: capture модели PaymentData.
        :type value: bool
        """
        self.__capture = value

    @property
    def client_ip(self):
        """Возвращает client_ip модели PaymentData.

        :return: client_ip модели PaymentData.
        :rtype: str
        """
        return self.__client_ip

    @client_ip.setter
    def client_ip(self, value):
        """Устанавливает client_ip модели PaymentData.

        :param value: client_ip модели PaymentData.
        :type value: str
        """
        self.__client_ip = value

    @property
    def description(self):
        """Возвращает description модели PaymentData.

        :return: description модели PaymentData.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """Устанавливает description модели PaymentData.

        :param value: description модели PaymentData.
        :type value: str
        """
        if value is not None and len(value) > 128:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `128`")  # noqa: E501
        self.__description = value

    @property
    def metadata(self):
        """Возвращает metadata модели PaymentData.

        :return: metadata модели PaymentData.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """Устанавливает metadata модели PaymentData.

        :param value: metadata модели PaymentData.
        :type value: dict[str, str]
        """
        if type(value) is dict:
            self.__metadata = value





# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject
from yookassa.domain.models.payment_data.payment_order.payment_order_recipient_bank_utilities import PaymentOrderRecipientBankUtilities


class PaymentOrderRecipientUtilities(BaseObject):
    """Получатель платежа"""  # noqa: E501

    __name = None
    """Название получателя."""  # noqa: E501

    __inn = None
    """ИНН получателя."""  # noqa: E501

    __kpp = None
    """КПП получателя."""  # noqa: E501

    __bank = None
    """Банк получателя.""" # noqa: E501

    @property
    def name(self):
        """Возвращает name модели PaymentOrderRecipient.

        :return: name модели PaymentOrderRecipient.
        :rtype: str
        """
        return self.__name

    @name.setter
    def name(self, value):
        """Устанавливает name модели PaymentOrderRecipient.

        :param value: name модели PaymentOrderRecipient.
        :type value: str
        """
        self.__name = value

    @property
    def inn(self):
        """Возвращает inn модели PaymentOrderRecipient.

        :return: inn модели PaymentOrderRecipient.
        :rtype: str
        """
        return self.__inn

    @inn.setter
    def inn(self, value):
        """Устанавливает inn модели PaymentOrderRecipient.

        :param value: inn модели PaymentOrderRecipient.
        :type value: str
        """
        if value is not None and not re.search(r'^[0-9]{10}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `inn`, must be a follow pattern or equal to `/[0-9]{10}/`")  # noqa: E501
        self.__inn = value

    @property
    def kpp(self):
        """Возвращает kpp модели PaymentOrderRecipient.

        :return: kpp модели PaymentOrderRecipient.
        :rtype: str
        """
        return self.__kpp

    @kpp.setter
    def kpp(self, value):
        """Устанавливает kpp модели PaymentOrderRecipient.

        :param value: kpp модели PaymentOrderRecipient.
        :type value: str
        """
        if value is not None and not re.search(r'^[0-9]{9}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `kpp`, must be a follow pattern or equal to `/[0-9]{9}/`")  # noqa: E501
        self.__kpp = value

    @property
    def bank(self):
        """Возвращает bank модели PaymentOrderRecipient.

        :return: bank модели PaymentOrderRecipient.
        :rtype: PaymentOrderRecipientBankUtilities
        """
        return self.__bank

    @bank.setter
    def bank(self, value):
        """Устанавливает bank модели PaymentOrderRecipient.

        :param value: bank модели PaymentOrderRecipient.
        :type value: PaymentOrderRecipientBankUtilities
        """
        if isinstance(value, dict):
            self.__bank = PaymentOrderRecipientBankUtilities(value)
        elif isinstance(value, PaymentOrderRecipientBankUtilities):
            self.__bank = value
        else:
            raise TypeError('Invalid bank type in PaymentOrderRecipient.bank')





# -*- coding: utf-8 -*-
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.models.payment_data.payment_order.payment_order_class_map import PaymentOrderClassMap


class PaymentOrderFactory(TypeFactory):
    """
    Фабрика создания объекта PaymentOrder по типу.
    """  # noqa: E501

    def __init__(self):
        super(PaymentOrderFactory, self).__init__(PaymentOrderClassMap())



# -*- coding: utf-8 -*-
from yookassa.domain.common.confirmation_type import ConfirmationType
from yookassa.domain.models.confirmation.confirmation import Confirmation


class ConfirmationQr(Confirmation):
    """
    Сценарий при котором для подтверждения платежа пользователю необходимо просканировать QR-код.
    От вас требуется сгенерировать QR-код, используя любой доступный инструмент, и отобразить его на странице оплаты.
    """  # noqa: E501

    __confirmation_data = None
    """Данные для генерации QR-кода. """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(ConfirmationQr, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not ConfirmationType.QR:
            self.type = ConfirmationType.QR

    @property
    def confirmation_data(self):
        """
        Возвращает confirmation_data модели ConfirmationQr.

        :return: confirmation_data модели ConfirmationQr.
        :rtype: str
        """
        return self.__confirmation_data

    @confirmation_data.setter
    def confirmation_data(self, value):
        """
        Устанавливает confirmation_data модели ConfirmationQr.

        :param value: confirmation_data модели ConfirmationQr.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            self.__confirmation_data = cast_value
        else:
            raise ValueError('Invalid confirmation_data value')



# -*- coding: utf-8 -*-
from yookassa.domain.models.self_employed_data.confirmation import SelfEmployedConfirmation, \
    SelfEmployedConfirmationType


class SelfEmployedConfirmationRedirect(SelfEmployedConfirmation):
    """
    Перенаправление пользователя на сайт сервиса Мой налог для выдачи прав ЮMoney.
    """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(SelfEmployedConfirmationRedirect, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not SelfEmployedConfirmationType.REDIRECT:
            self.type = SelfEmployedConfirmationType.REDIRECT



# -*- coding: utf-8 -*-
from yookassa.domain.common import RequestObject


class Statement(RequestObject):
    """
    Данные для отправки справки. Необходимо передавать, если вы хотите, чтобы после оплаты пользователь получил справку. Сейчас доступен один тип справок — квитанция по платежу. Это информация об успешном платеже, которую ЮKassa отправляет на электронную почту пользователя.
    """  # noqa: E501

    __type = None
    """Тип справки."""  # noqa: E501

    @property
    def type(self):
        """
        Возвращает type модели Statement.

        :return: type модели Statement.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """
        Устанавливает type модели Statement.

        :param value: type модели Statement.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self.__type = str(value)



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject
from yookassa.domain.models.payment_data.request.merchant_customer_bank_account import MerchantCustomerBankAccount


class FraudData(BaseObject):
    """
    Информация для проверки операции на мошенничество.
    """  # noqa: E501

    __topped_up_phone = None
    """Номер телефона для пополнения. Не более 15 символов. Пример: ~`79110000000`.<br/> Необходим при %[пополнении баланса телефона](/developers/payment-acceptance/scenario-extensions/top-up-phones-balance). """  # noqa: E501

    __merchant_customer_bank_account = None
    """Данные банковского счета, открытого в вашей системе."""  # noqa: E501

    @property
    def topped_up_phone(self):
        """
        Возвращает topped_up_phone модели FraudData.

        :return: topped_up_phone модели FraudData.
        :rtype: str
        """
        return self.__topped_up_phone

    @topped_up_phone.setter
    def topped_up_phone(self, value):
        """
        Устанавливает topped_up_phone модели FraudData.

        :param value: topped_up_phone модели FraudData.
        :type value: str
        """
        if value is not None and not re.search(r'^[0-9]{4,15}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `topped_up_phone`, must be a follow pattern or equal to `/[0-9]{4,15}/`")  # noqa: E501
        self.__topped_up_phone = value

    @property
    def merchant_customer_bank_account(self):
        """
        Возвращает merchant_customer_bank_account модели FraudData.

        :return: merchant_customer_bank_account модели FraudData.
        :rtype: MerchantCustomerBankAccount
        """
        return self.__merchant_customer_bank_account

    @merchant_customer_bank_account.setter
    def merchant_customer_bank_account(self, value):
        """
        Устанавливает merchant_customer_bank_account модели FraudData.

        :param value: merchant_customer_bank_account модели FraudData.
        :type value: MerchantCustomerBankAccount
        """
        if isinstance(value, dict):
            self.__merchant_customer_bank_account = MerchantCustomerBankAccount(value)
        elif isinstance(value, MerchantCustomerBankAccount):
            self.__merchant_customer_bank_account = value
        else:
            raise TypeError('Invalid merchant_customer_bank_account data type in FraudData.merchant_customer_bank_account')  # noqa: E501



# -*- coding: utf-8 -*-
from yookassa.domain.request.payment_method_request import PaymentMethodRequest
from yookassa.domain.models.payment_method.request.payment_method_holder import PaymentMethodHolder
from yookassa.domain.models.payment_data.request.credit_card import CreditCard


class PaymentMethodRequestBuilder(object):
    """
    Конструктор запроса для проверки и сохранения способа оплаты.
    """  # noqa: E501

    def __init__(self):
        self.__request = PaymentMethodRequest()

    def set_type(self, value):
        """
        Устанавливает type модели PaymentMethodRequestBuilder.

        :param value: type модели PaymentMethodRequestBuilder.
        :type value: str
        :rtype: PaymentMethodRequestBuilder
        """
        self.__request.type = value
        return self

    def set_card(self, value):
        """
        Устанавливает card модели PaymentMethodRequestBuilder.

        :param value: card модели PaymentMethodRequestBuilder.
        :type value: CreditCard
        :rtype: PaymentMethodRequestBuilder
        """
        self.__request.card = value
        return self

    def set_holder(self, value):
        """
        Устанавливает holder модели PaymentMethodRequestBuilder.

        :param value: holder модели PaymentMethodRequestBuilder.
        :type value: PaymentMethodHolder
        :rtype: PaymentMethodRequestBuilder
        """
        self.__request.holder = value
        return self

    def set_client_ip(self, value):
        """
        Устанавливает client_ip модели PaymentMethodRequestBuilder.

        :param value: client_ip модели PaymentMethodRequestBuilder.
        :type value: str
        :rtype: PaymentMethodRequestBuilder
        """
        self.__request.client_ip = value
        return self

    def set_confirmation(self, value):
        """
        Устанавливает confirmation модели PaymentMethodRequestBuilder.

        :param value: confirmation модели PaymentMethodRequestBuilder.
        :type value: ConfirmationRequest
        :rtype: PaymentMethodRequestBuilder
        """
        self.__request.confirmation = value
        return self

    def build(self):
        """
        Возвращает request модели PaymentMethodRequestBuilder.

        :return: request модели PaymentMethodRequestBuilder.
        :rtype: PaymentMethodRequest
        """
        return self.__request



# -*- coding: utf-8 -*-

class PaymentOrderType:
    """
    Константы, представляющие значения payment_order_type. Возможные значения:

    * utilities - Оплата ЖКУ
    """  # noqa: E501

    """
    Список допустимых значений
    """
    UTILITIES = 'utilities'
    """Оплата ЖКУ"""



# coding: utf-8
import datetime

from yookassa.domain.request.invoice_request import InvoiceRequest


class InvoiceRequestBuilder(object):
    """Конструктор запроса на создание нового счета."""  # noqa: E501

    def __init__(self):
        self.__request = InvoiceRequest()

    def set_payment_data(self, value):
        """Устанавливает payment_data модели InvoiceRequest.

        :param value: payment_data модели InvoiceRequest.
        :type value: PaymentData
        :rtype: InvoiceRequestBuilder
        """
        self.__request.payment_data = value
        return self

    def set_cart(self, value):
        """Устанавливает cart модели InvoiceRequest.

        :param value: cart модели InvoiceRequest.
        :type value: list[LineItem]
        :rtype: InvoiceRequestBuilder
        """
        self.__request.cart = value
        return self

    def set_delivery_method_data(self, value):
        """Устанавливает delivery_method_data модели InvoiceRequest.

        :param value: delivery_method_data модели InvoiceRequest.
        :type value: DeliveryMethod
        :rtype: InvoiceRequestBuilder
        """
        self.__request.delivery_method_data = value
        return self

    def set_expires_at(self, value):
        """Устанавливает expires_at модели InvoiceRequest.

        :param value: expires_at модели InvoiceRequest.
        :type value: datetime
        :rtype: InvoiceRequestBuilder
        """
        self.__request.expires_at = value
        return self

    def set_locale(self, value):
        """Устанавливает locale модели InvoiceRequest.

        :param value: locale модели InvoiceRequest.
        :type value: str
        :rtype: InvoiceRequestBuilder
        """
        self.__request.locale = value
        return self

    def set_description(self, value):
        """Устанавливает description модели InvoiceRequest.

        :param value: description модели InvoiceRequest.
        :type value: str
        :rtype: InvoiceRequestBuilder
        """
        self.__request.description = value
        return self

    def set_metadata(self, value):
        """Устанавливает metadata модели InvoiceRequest.

        :param value: metadata модели InvoiceRequest.
        :type value: dict[str, str]
        :rtype: InvoiceRequestBuilder
        """
        self.__request.metadata = value

    def build(self):
        """
        Возвращает request модели InvoiceRequestBuilder.

        :return: request модели InvoiceRequestBuilder.
        :rtype: InvoiceRequest
        """
        return self.__request



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payout_data.payout_destination import PayoutDestination


class PayoutDestinationSbp(PayoutDestination):
    """
    Данные для выплаты на счет в банке через систему быстрых платежей.
    """  # noqa: E501

    __phone = None
    """Телефон, к которому привязан счет получателя выплаты в системе участника СБП."""  # noqa: E501

    __bank_id = None
    """Идентификатор выбранного участника СБП — банка или платежного сервиса, подключенного к сервису. Максимум 12 символов. %[Как получить идентификатор участника СБП](/developers/payouts/making-payouts/sbp) """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PayoutDestinationSbp, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.SBP:
            self.type = PaymentMethodType.SBP

    @property
    def phone(self):
        """
        Возвращает phone модели PayoutDestinationSbp.

        :return: phone модели PayoutDestinationSbp.
        :rtype: str
        """
        return self.__phone

    @phone.setter
    def phone(self, value):
        """
        Устанавливает phone модели PayoutDestinationSbp.

        :param value: phone модели PayoutDestinationSbp.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `phone`, must not be `None`")  # noqa: E501
        self.__phone = value

    @property
    def bank_id(self):
        """
        Возвращает bank_id модели PayoutDestinationSbp.

        :return: bank_id модели PayoutDestinationSbp.
        :rtype: str
        """
        return self.__bank_id

    @bank_id.setter
    def bank_id(self, value):
        """
        Устанавливает bank_id модели PayoutDestinationSbp.

        :param value: bank_id модели PayoutDestinationSbp.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `bank_id`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 12:
            raise ValueError("Invalid value for `bank_id`, length must be less than or equal to `12`")  # noqa: E501
        if value is not None and not re.search(r'^[a-zA-Z0-9]{12}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `bank_id`, must be a follow pattern or equal to `/[a-zA-Z0-9]{12}/`")  # noqa: E501
        self.__bank_id = value




# -*- coding: utf-8 -*-
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.models.self_employed_data.confirmation_class_map import SelfEmployedConfirmationClassMap


class SelfEmployedConfirmationFactory(TypeFactory):
    """
    Фабрика создания объекта SelfEmployedConfirmation по типу.
    """  # noqa: E501

    def __init__(self):
        super(SelfEmployedConfirmationFactory, self).__init__(SelfEmployedConfirmationClassMap())



# -*- coding: utf-8 -*-
from yookassa.domain.common.request_object import RequestObject
from yookassa.domain.models.self_employed_data.confirmation import SelfEmployedConfirmation
from yookassa.domain.models.self_employed_data.confirmation_factory import SelfEmployedConfirmationFactory

DESCRIPTION_MAX_LENGTH = 128


class SelfEmployedRequest(RequestObject):
    """
    Объект запроса к API на создание объекта самозанятого.
    """  # noqa: E501

    __itn = None
    """ИНН самозанятого. Формат: 12 цифр без пробелов. Обязательный параметр, если не передан phone."""  # noqa: E501

    __phone = None
    """Телефон самозанятого, который привязан к личному кабинету в сервисе Мой налог."""  # noqa: E501

    __confirmation = None
    """Сценарий подтверждения пользователем заявки ЮMoney на получение прав для регистрации чеков в сервисе Мой налог."""  # noqa: E501

    __description = None
    """Описание к созданию самозанятого."""

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    @property
    def itn(self):
        """
        Возвращает itn модели SelfEmployedRequest.

        :return: itn модели SelfEmployedRequest.
        :rtype: str
        """
        return self.__itn

    @itn.setter
    def itn(self, value):
        """
        Устанавливает itn модели SelfEmployedRequest.

        :param value: itn модели SelfEmployedRequest.
        :type value: str
        """
        self.__itn = value

    @property
    def phone(self):
        """
        Возвращает phone модели SelfEmployedRequest.

        :return: phone модели SelfEmployedRequest.
        :rtype: str
        """
        return self.__phone

    @phone.setter
    def phone(self, value):
        """
        Устанавливает phone модели SelfEmployedRequest.

        :param value: phone модели SelfEmployedRequest.
        :type value: str
        """
        self.__phone = str(value)

    @property
    def confirmation(self):
        """
        Возвращает confirmation модели SelfEmployedRequest.

        :return: confirmation модели SelfEmployedRequest.
        :rtype: SelfEmployedConfirmation
        """
        return self.__confirmation

    @confirmation.setter
    def confirmation(self, value):
        """
        Устанавливает confirmation модели SelfEmployedRequest.

        :param value: confirmation модели SelfEmployedRequest.
        :type value: SelfEmployedConfirmation
        """
        if isinstance(value, dict):
            self.__confirmation = SelfEmployedConfirmationFactory().create(value, self.context())
        elif isinstance(value, SelfEmployedConfirmation):
            self.__confirmation = value
        else:
            raise TypeError('Invalid confirmation data type in SelfEmployedRequest.confirmation')

    @property
    def description(self):
        """
        Возвращает description модели SelfEmployedRequest.

        :return: description модели SelfEmployedRequest.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели SelfEmployedRequest.

        :param value: description модели SelfEmployedRequest.
        :type value: str
        """
        if value is not None and len(value) > DESCRIPTION_MAX_LENGTH:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `{}`".format(DESCRIPTION_MAX_LENGTH))  # noqa: E501
        self.__description = value

    @property
    def metadata(self):
        """
        Возвращает metadata модели SelfEmployedRequest.

        :return: metadata модели SelfEmployedRequest.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели SelfEmployedRequest.

        :param value: metadata модели SelfEmployedRequest.
        :type value: dict[str, str]
        """
        self.__metadata = value

    def validate(self):
        """
        Влидация данных модели SelfEmployedRequest.
        """
        if self.itn is None and self.phone is None:
            self.__set_validation_error('Both itn and phone values are empty in self_employed_request')

    def __set_validation_error(self, message):
        """
        Устанавливает message в Exception при валидации модели SelfEmployedRequest.

        :param message: message модели Exception.
        :type message: str
        """
        raise ValueError(message)



# -*- coding: utf-8 -*-
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.models.refund_data.refund_data_class_map import RefundDataClassMap


class RefundDataFactory(TypeFactory):
    """
    Фабрика создания объекта RefundData по типу.
    """  # noqa: E501

    def __init__(self):
        super(RefundDataFactory, self).__init__(RefundDataClassMap())



# -*- coding: utf-8 -*-
"""Top-level package for YooKassa API Python Client Library."""

from yookassa.domain.request.capture_payment_builder import CapturePaymentBuilder
from yookassa.domain.request.capture_payment_request import CapturePaymentRequest
from yookassa.domain.request.payment_request import PaymentRequest
from yookassa.domain.request.payment_request_builder import PaymentRequestBuilder
from yookassa.domain.request.receipt_item_request import ReceiptItemRequest
from yookassa.domain.request.receipt_request import ReceiptRequest
from yookassa.domain.request.receipt_request_builder import ReceiptRequestBuilder
from yookassa.domain.request.refund_request import RefundRequest
from yookassa.domain.request.refund_request_builder import RefundRequestBuilder
from yookassa.domain.request.webhook_request import WebhookRequest
from yookassa.domain.request.deal_request import DealRequest
from yookassa.domain.request.deal_request_builder import DealRequestBuilder
from yookassa.domain.request.invoice_request_builder import InvoiceRequestBuilder
from yookassa.domain.request.invoice_request import InvoiceRequest
from yookassa.domain.request.payout_request import PayoutRequest
from yookassa.domain.request.payout_request_builder import PayoutRequestBuilder
from yookassa.domain.request.personal_data_request import SbpPayoutRecipientPersonalDataRequest, \
    PayoutStatementRecipientPersonalDataRequest, PersonalDataRequestFactory
from yookassa.domain.request.self_employed_request import SelfEmployedRequest
from yookassa.domain.request.self_employed_request_builder import SelfEmployedRequestBuilder
from yookassa.domain.request.payment_method_request import PaymentMethodRequest
from yookassa.domain.request.payment_method_request_builder import PaymentMethodRequestBuilder



# -*- coding: utf-8 -*-


class Context(object):
    """
    Базовый контекстный класс.
    """  # noqa: E501

    def __init__(self, contexts):
        self.__contexts = contexts

    def get_context_data(self, context):
        """
        Возвращает контекстные данные

        :param context: mixed
        :return: mixed
        """
        if context in self.__contexts:
            return getattr(self, context)



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class AdditionalUserProps(BaseObject):
    """
    Дополнительный реквизит пользователя (тег в 54 ФЗ — 1084). <br/>Можно передавать, если вы отправляете данные для формирования чека по сценарию %[Сначала платеж, потом чек](/developers/payment-acceptance/receipts/54fz/other-services/basics#receipt-after-payment) 
    """  # noqa: E501

    __name = None
    """Наименование дополнительного реквизита пользователя (тег в 54 ФЗ — 1085). Не более 64 символов. """  # noqa: E501

    __value = None
    """Значение дополнительного реквизита пользователя (тег в 54 ФЗ — 1086). Не более 234 символов. """  # noqa: E501

    @property
    def name(self):
        """
        Возвращает name модели AdditionalUserProps.

        :return: name модели AdditionalUserProps.
        :rtype: str
        """
        return self.__name

    @name.setter
    def name(self, value):
        """
        Устанавливает name модели AdditionalUserProps.

        :param value: name модели AdditionalUserProps.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 64:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        self.__name = value

    @property
    def value(self):
        """
        Возвращает value модели AdditionalUserProps.

        :return: value модели AdditionalUserProps.
        :rtype: str
        """
        return self.__value

    @value.setter
    def value(self, value):
        """
        Устанавливает value модели AdditionalUserProps.

        :param value: value модели AdditionalUserProps.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 234:
            raise ValueError("Invalid value for `value`, length must be less than or equal to `234`")  # noqa: E501
        self.__value = value



# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payment_data.payment_data import PaymentData


class PaymentDataGooglePay(PaymentData):
    """
    Платежные данные для проведения оплаты при помощи Google Pay.
    """  # noqa: E501

    __payment_method_token = None
    """Криптограмма Payment Token Cryptography для проведения оплаты через Google Pay."""  # noqa: E501

    __google_transaction_id = None
    """Уникальный идентификатор транзакции, выданный Google."""  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentDataGooglePay, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.GOOGLE_PAY:
            self.type = PaymentMethodType.GOOGLE_PAY

    @property
    def payment_method_token(self):
        """
        Возвращает payment_method_token модели PaymentDataGooglePay.

        :return: payment_method_token модели PaymentDataGooglePay.
        :rtype: str
        """
        return self.__payment_method_token

    @payment_method_token.setter
    def payment_method_token(self, value):
        """
        Устанавливает payment_method_token модели PaymentDataGooglePay.

        :param value: payment_method_token модели PaymentDataGooglePay.
        :type value: str
        """
        self.__payment_method_token = str(value)

    @property
    def google_transaction_id(self):
        """
        Возвращает google_transaction_id модели PaymentDataGooglePay.

        :return: google_transaction_id модели PaymentDataGooglePay.
        :rtype: str
        """
        return self.__google_transaction_id

    @google_transaction_id.setter
    def google_transaction_id(self, value):
        """
        Устанавливает google_transaction_id модели PaymentDataGooglePay.

        :param value: google_transaction_id модели PaymentDataGooglePay.
        :type value: str
        """
        self.__google_transaction_id = str(value)



# -*- coding: utf-8 -*-
from yookassa.domain.exceptions.api_error import ApiError


class GoneError(ApiError):
    """
    Сущность была раньше, но была умышленно удалена и теперь недоступна.
    """  # noqa: E501
    HTTP_CODE = 410



# -*- coding: utf-8 -*-
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.models.payout_data.payout_destination_class_map import PayoutDestinationClassMap


class PayoutDestinationFactory(TypeFactory):
    """
    Фабрика создания объекта PayoutDestination по типу.
    """  # noqa: E501

    def __init__(self):
        super(PayoutDestinationFactory, self).__init__(PayoutDestinationClassMap())



# coding: utf-8
import datetime

from yookassa.domain.common import BaseObject, RequestObject
from yookassa.domain.models.invoice import LineItem
from yookassa.domain.models.invoice_data.delivery_method import DeliveryMethod
from yookassa.domain.models.invoice_data.delivery_method_factory import DeliveryMethodFactory
from yookassa.domain.models.invoice_data.request.payment_data import PaymentData

DESCRIPTION_MAX_LENGTH = 128


class InvoiceRequest(RequestObject):
    """Класс, представляющий модель InvoiceRequest."""  # noqa: E501

    __payment_data = None
    """Данные для проведения платежа по выставленному счету."""  # noqa: E501

    __cart = None
    """Корзина заказа — список товаров или услуг, который отобразится на странице счета перед оплатой."""  # noqa: E501

    __delivery_method_data = None
    """
    Данные о способе доставки счета пользователю.
    Доступен только один способ — самостоятельная доставка: ЮKassa возвращает вам ссылку на счет, и вы передаете ее пользователю любым удобным для вас способом.
    """  # noqa: E501

    __expires_at = None
    """Срок действия счета — дата и время, до которых можно оплатить выставленный счет. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2024-10-18T10:51:18.139Z` """  # noqa: E501

    __locale = None
    """
    Язык интерфейса, писем и смс, которые будет видеть или получать пользователь.
    Формат соответствует [ISO/IEC 15897](https://en.wikipedia.org/wiki/Locale_(computer_software)).
    Возможные значения: ru_RU, en_US. Регистр важен.
    """

    __description = None
    """Описание выставленного счета (не более 128 символов), которое вы увидите в личном кабинете ЮKassa, а пользователь на странице счета. Например: «Счет на оплату по договору 37». """  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    @property
    def payment_data(self):
        """Возвращает payment_data модели InvoiceRequest.

        :return: payment_data модели InvoiceRequest.
        :rtype: PaymentData
        """
        return self.__payment_data

    @payment_data.setter
    def payment_data(self, value):
        """Устанавливает payment_data модели InvoiceRequest.

        :param value: payment_data модели InvoiceRequest.
        :type value: PaymentData
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `payment_data`, must not be `None`")  # noqa: E501
        if isinstance(value, dict):
            self.__payment_data = PaymentData(value)
        elif isinstance(value, PaymentData):
            self.__payment_data = value
        else:
            raise TypeError('Invalid payment_data data type in InvoiceRequest.payment_data')

    @property
    def cart(self):
        """Возвращает cart модели InvoiceRequest.

        :return: cart модели InvoiceRequest.
        :rtype: list[LineItem]
        """
        return self.__cart

    @cart.setter
    def cart(self, value):
        """Устанавливает cart модели InvoiceRequest.

        :param value: cart модели InvoiceRequest.
        :type value: list[LineItem]
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `cart`, must not be `None`")  # noqa: E501
        if isinstance(value, list):
            cart_array = []
            for cart_data in value:
                if isinstance(cart_data, dict):
                    cart_array.append(LineItem(cart_data))
                elif isinstance(cart_data, LineItem):
                    cart_array.append(cart_data)
                else:
                    raise TypeError('Invalid cart data type in InvoiceRequest.cart')

            self.__cart = cart_array
        else:
            raise TypeError('Invalid cart value type in InvoiceRequest')

    @property
    def delivery_method_data(self):
        """Возвращает delivery_method_data модели InvoiceRequest.

        :return: delivery_method_data модели InvoiceRequest.
        :rtype: DeliveryMethod
        """
        return self.__delivery_method_data

    @delivery_method_data.setter
    def delivery_method_data(self, value):
        """Устанавливает delivery_method_data модели InvoiceRequest.

        :param value: delivery_method_data модели InvoiceRequest.
        :type value: DeliveryMethod
        """
        if isinstance(value, dict):
            self.__delivery_method_data = DeliveryMethodFactory().create(value, self.context())
        elif isinstance(value, DeliveryMethod):
            self.__delivery_method_data = value
        else:
            raise TypeError('Invalid delivery_method_data data type in InvoiceRequest.delivery_method_data')

    @property
    def expires_at(self):
        """Возвращает expires_at модели InvoiceRequest.

        :return: expires_at модели InvoiceRequest.
        :rtype: datetime
        """
        return self.__expires_at

    @expires_at.setter
    def expires_at(self, value):
        """Устанавливает expires_at модели InvoiceRequest.

        :param value: expires_at модели InvoiceRequest.
        :type value: datetime
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `expires_at`, must not be `None`")  # noqa: E501
        self.__expires_at = value

    @property
    def locale(self):
        """Возвращает locale модели InvoiceRequest.

        :return: locale модели InvoiceRequest.
        :rtype: str
        """
        return self.__locale

    @locale.setter
    def locale(self, value):
        """Устанавливает locale модели InvoiceRequest.

        :param value: locale модели InvoiceRequest.
        :type value: str
        """
        self.__locale = value

    @property
    def description(self):
        """Возвращает description модели InvoiceRequest.

        :return: description модели InvoiceRequest.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """Устанавливает description модели InvoiceRequest.

        :param value: description модели InvoiceRequest.
        :type value: str
        """
        if value is not None and len(value) > DESCRIPTION_MAX_LENGTH:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `{}`".format(DESCRIPTION_MAX_LENGTH))  # noqa: E501
        self.__description = value

    @property
    def metadata(self):
        """Возвращает metadata модели InvoiceRequest.

        :return: metadata модели InvoiceRequest.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """Устанавливает metadata модели InvoiceRequest.

        :param value: metadata модели InvoiceRequest.
        :type value: dict[str, str]
        """
        self.__metadata = value


    def validate(self):
        """
        Влидация данных модели PaymentRequest.
        """
        if self.payment_data is None:
            self.__set_validation_error('Payment data not specified')

        amount = self.payment_data.amount
        if amount is None:
            self.__set_validation_error('Payment amount not specified')

        if amount.value <= 0.0:
            self.__set_validation_error('Invalid payment amount value: ' + str(amount.value))

        if self.payment_data.receipt is not None and self.payment_data.receipt.has_items:
            if self.payment_data.receipt.customer is None:
                self.__set_validation_error('Customer is empty in InvoiceRequest.payment_data.receipt')

            email = self.payment_data.receipt.customer.email
            phone = self.payment_data.receipt.customer.phone
            if not email and not phone:
                self.__set_validation_error('Both email and phone values are empty in InvoiceRequest.payment_data.receipt.customer')

            if self.payment_data.receipt.tax_system_code is None:
                for item in self.payment_data.receipt.items:
                    if item.vat_code is None:
                        self.__set_validation_error('Item vat_code and receipt tax_system_id not specified in InvoiceRequest.payment_data.receipt')

    def __set_validation_error(self, message):
        """
        Устанавливает message в Exception при валидации модели PaymentRequest.

        :param message: message модели Exception.
        :type message: str
        """
        raise ValueError(message)



# -*- coding: utf-8 -*-


class WebhookNotificationType:
    """
    Тип уведомления.
    """  # noqa: E501

    """
    Список допустимых значений
    """
    NOTIFICATION = 'notification'
    """Уведомление."""


class WebhookNotificationEventType:
    """
    Тип события.
    """  # noqa: E501

    """
    Список допустимых значений
    """
    PAYMENT_WAITING_FOR_CAPTURE = 'payment.waiting_for_capture'
    """Успешно оплачен покупателем, ожидает подтверждения магазином."""
    PAYMENT_SUCCEEDED = 'payment.succeeded'
    """Успешно оплачен и подтвержден магазином."""
    PAYMENT_CANCELED = 'payment.canceled'
    """Неуспех оплаты или отменен магазином."""
    REFUND_SUCCEEDED = 'refund.succeeded'
    """Успешный возврат."""
    DEAL_CLOSED = 'deal.closed'
    """Сделка перешла в статус closed."""
    PAYOUT_CANCELED = 'payout.canceled'
    """Выплата перешла в статус canceled."""
    PAYOUT_SUCCEEDED = 'payout.succeeded'
    """Выплата перешла в статус succeeded."""



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common import BaseObject


class ReceiptCustomer(BaseObject):
    """
    Информация о пользователе. Необходимо указать как минимум контактные данные: для Чеков от ЮKassa — электронную почту (`customer.email`), в остальных случаях — электронную почту (`customer.email`) или номер телефона (`customer.phone`). 
    """  # noqa: E501

    __full_name = None
    """Для юрлица — название организации, для ИП и физического лица — ФИО. Если у физлица отсутствует ИНН, в этом же параметре передаются паспортные данные. Не более 256 символов. <br/>Можно передавать, если используете Чеки от ЮKassa или онлайн-кассу Orange Data, Атол Онлайн. """  # noqa: E501

    __inn = None
    """ИНН плательщика (10 или 12 цифр)."""  # noqa: E501

    __email = None
    """E-mail адрес плательщика на который будет выслан чек."""  # noqa: E501

    __phone = None
    """Номер телефона плательщика в формате ITU-T E.164 на который будет выслан чек."""  # noqa: E501

    @property
    def full_name(self):
        """
        Возвращает full_name модели ReceiptCustomer.

        :return: full_name модели ReceiptCustomer.
        :rtype: str
        """
        return self.__full_name

    @full_name.setter
    def full_name(self, value):
        """
        Устанавливает full_name модели ReceiptCustomer.

        :param value: full_name модели ReceiptCustomer.
        :type value: str
        """
        self.__full_name = str(value)

    @property
    def inn(self):
        """
        Возвращает inn модели ReceiptCustomer.

        :return: inn модели ReceiptCustomer.
        :rtype: str
        """
        return self.__inn

    @inn.setter
    def inn(self, value):
        """
        Устанавливает inn модели ReceiptCustomer.

        :param value: inn модели ReceiptCustomer.
        :type value: str
        """
        self.__inn = str(value)

    @property
    def email(self):
        """
        Возвращает email модели ReceiptCustomer.

        :return: email модели ReceiptCustomer.
        :rtype: str
        """
        return self.__email

    @email.setter
    def email(self, value):
        """
        Устанавливает email модели ReceiptCustomer.

        :param value: email модели ReceiptCustomer.
        :type value: str
        """
        cast_value = str(value)
        if re.match(r"^[^@]+@[^@]+\.[^@]+$", cast_value):
            self.__email = cast_value
        else:
            raise ValueError('Invalid email value type')

    @property
    def phone(self):
        """
        Возвращает phone модели ReceiptCustomer.

        :return: phone модели ReceiptCustomer.
        :rtype: str
        """
        return self.__phone

    @phone.setter
    def phone(self, value):
        """
        Устанавливает phone модели ReceiptCustomer.

        :param value: phone модели ReceiptCustomer.
        :type value: str
        """
        self.__phone = str(value)



# -*- coding: utf-8 -*-
import uuid

from yookassa.client import ApiClient
from yookassa.domain.common.http_verb import HttpVerb
from yookassa.domain.request.receipt_request import ReceiptRequest
from yookassa.domain.response.receipt_list_response import ReceiptListResponse
from yookassa.domain.response.receipt_response import ReceiptResponse


class Receipt:
    """
    Класс, представляющий модель Receipt.
    """  # noqa: E501

    base_path = '/receipts'

    def __init__(self):
        self.client = ApiClient()

    @classmethod
    def find_one(cls, receipt_id):
        """
        Возвращает информацию о чеке

        :param receipt_id: Уникальный идентификатор чека
        :return: ReceiptResponse Объект ответа, возвращаемого API при запросе информации о чеке
        """
        instance = cls()
        if not isinstance(receipt_id, str) or not receipt_id:
            raise ValueError('Invalid payment_id value')

        path = instance.base_path + '/' + receipt_id
        response = instance.client.request(HttpVerb.GET, path)
        return ReceiptResponse(response)

    @classmethod
    def create(cls, params, idempotency_key=None):
        """
        Создание чека

        :param params: Данные передаваемые в API
        :param idempotency_key: Ключ идемпотентности
        :return: ReceiptResponse Объект ответа, возвращаемого API при запросе информации о чеке
        """
        instance = cls()
        path = cls.base_path

        if not idempotency_key:
            idempotency_key = uuid.uuid4()

        headers = {
            'Idempotence-Key': str(idempotency_key)
        }

        if isinstance(params, dict):
            params_object = ReceiptRequest(params)
        elif isinstance(params, ReceiptRequest):
            params_object = params
        else:
            raise TypeError('Invalid params value type')

        response = instance.client.request(HttpVerb.POST, path, None, headers, params_object)
        return ReceiptResponse(response)

    @classmethod
    def list(cls, params):
        """
        Возвращает список чеков

        :param params: Данные передаваемые в API
        :return: ReceiptListResponse Объект ответа, возвращаемого API при запросе списка чеков
        """
        instance = cls()
        path = cls.base_path

        response = instance.client.request(HttpVerb.GET, path, params)
        return ReceiptListResponse(response)



# -*- coding: utf-8 -*-
from yookassa.domain.common.confirmation_type import ConfirmationType
from yookassa.domain.models.confirmation.request.confirmation_request import ConfirmationRequest


class ConfirmationEmbedded(ConfirmationRequest):
    """
    Действия, необходимые для подтверждения платежа, будут зависеть от способа оплаты, который пользователь выберет в виджете ЮKassa.
    Подтверждение от пользователя получит ЮKassa — вам необходимо только встроить виджет к себе на страницу.
    """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(ConfirmationEmbedded, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not ConfirmationType.EMBEDDED:
            self.type = ConfirmationType.EMBEDDED



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.models import Amount
from yookassa.domain.models.payment_data.payment_order.payment_order import PaymentOrder
from yookassa.domain.models.payment_data.payment_order.payment_order_recipient_utilities import PaymentOrderRecipientUtilities
from yookassa.domain.models.payment_data.payment_order.payment_order_type import PaymentOrderType
from yookassa.domain.models.payment_data.payment_order.payment_period import PaymentPeriod


class PaymentOrderUtilities(PaymentOrder):
    """Платежное поручение — распоряжение на перевод банку для оплаты жилищно-коммунальных услуг (ЖКУ), сведения о платеже для регистрации в ГИС ЖКХ.  Необходимо передавать при %[оплате ЖКУ](/developers/payment-acceptance/scenario-extensions/utility-payments).  Кроме параметров, отмеченных как обязательные, должен быть передан как минимум один параметр из этого списка: `payment_document_id`, `payment_document_number`, `account_number`, `unified_account_number` или `service_id`. """  # noqa: E501

    __amount = None
    """Сумма платежного поручения — сумма, которую пользователь переводит получателю платежа. Равна общей сумме платежа."""

    __payment_purpose = None
    """Назначение платежа (не больше 210 символов)."""

    __recipient = None
    """Получатель платежа — государственная или коммерческая организация, которая предоставляет услуги или является информационным посредником, который собирает и обрабатывает начисления от других поставщиков услуг."""

    __kbk = None
    """Код бюджетной классификации (КБК)."""  # noqa: E501

    __oktmo = None
    """Код ОКТМО (Общероссийский классификатор территорий муниципальных образований)."""  # noqa: E501

    __payment_period = None
    """Период оплаты, за который выставлены начисления и за который вносится оплата."""

    __payment_document_id = None
    """Идентификатор платежного документа.  Обязательный параметр, если не передан `payment_document_number`, `account_number`, `unified_account_number` или `service_id`. """  # noqa: E501

    __payment_document_number = None
    """Номер платежного документа на стороне поставщика ЖКУ.  Обязательный параметр, если не передан `payment_document_id`, `account_number`, `unified_account_number` или `service_id`. """  # noqa: E501

    __account_number = None
    """Номер лицевого счета на стороне поставщика ЖКУ.  Обязательный параметр, если не передан `payment_document_id`, `payment_document_number`, `unified_account_number` или `service_id`. """  # noqa: E501

    __unified_account_number = None
    """Единый лицевой счет. Уникальный идентификатор в ГИС ЖКХ, который характеризует связку «собственник-помещение».  Обязательный параметр, если не передан `payment_document_id`, `payment_document_number`, `account_number` или `service_id`. """  # noqa: E501

    __service_id = None
    """Идентификатор жилищно-коммунальной услуги (ЖКУ).  Обязательный параметр, если не передан `payment_document_id`, `payment_document_number`, `account_number` или `unified_account_number`. """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(PaymentOrderUtilities, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentOrderType.UTILITIES:
            self.type = PaymentOrderType.UTILITIES

    @property
    def amount(self):
        """Возвращает amount модели PaymentOrderUtilities.

        :return: amount модели PaymentOrderUtilities.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """Устанавливает amount модели PaymentOrderUtilities.

        :param value: amount модели PaymentOrderUtilities.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def payment_purpose(self):
        """Возвращает payment_purpose модели PaymentOrderUtilities.

        :return: payment_purpose модели PaymentOrderUtilities.
        :rtype: str
        """
        return self.__payment_purpose

    @payment_purpose.setter
    def payment_purpose(self, value):
        """Устанавливает payment_purpose модели PaymentOrderUtilities.

        :param value: payment_purpose модели PaymentOrderUtilities.
        :type value: str
        """
        self.__payment_purpose = value

    @property
    def recipient(self):
        """Возвращает recipient модели PaymentOrderUtilities.

        :return: recipient модели PaymentOrderUtilities.
        :rtype: PaymentOrderRecipientUtilities
        """
        return self.__recipient

    @recipient.setter
    def recipient(self, value):
        """Устанавливает recipient модели PaymentOrderUtilities.

        :param value: recipient модели PaymentOrderUtilities.
        :type value: PaymentOrderRecipientUtilities
        """
        if isinstance(value, dict):
            self.__recipient = PaymentOrderRecipientUtilities(value)
        elif isinstance(value, PaymentOrderRecipientUtilities):
            self.__recipient = value
        else:
            raise TypeError('Invalid recipient data type in PaymentOrderUtilities.recipient')

    @property
    def kbk(self):
        """Возвращает kbk модели PaymentOrderUtilities.

        :return: kbk модели PaymentOrderUtilities.
        :rtype: str
        """
        return self.__kbk

    @kbk.setter
    def kbk(self, value):
        """Устанавливает kbk модели PaymentOrderUtilities.

        :param value: kbk модели PaymentOrderUtilities.
        :type value: str
        """
        if value is not None and len(value) > 20:
            raise ValueError("Invalid value for `kbk`, length must be less than or equal to `20`")  # noqa: E501
        if value is not None and len(value) < 1:
            raise ValueError("Invalid value for `kbk`, length must be greater than or equal to `1`")  # noqa: E501
        if value is not None and not re.search(r'^(\d{20})|(0)$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `kbk`, must be a follow pattern or equal to `/(\d{20})|(0)/`")  # noqa: E501
        self.__kbk = value

    @property
    def oktmo(self):
        """Возвращает oktmo модели PaymentOrderUtilities.

        :return: oktmo модели PaymentOrderUtilities.
        :rtype: str
        """
        return self.__oktmo

    @oktmo.setter
    def oktmo(self, value):
        """Устанавливает oktmo модели PaymentOrderUtilities.

        :param value: oktmo модели PaymentOrderUtilities.
        :type value: str
        """
        if value is not None and len(value) > 8:
            raise ValueError("Invalid value for `oktmo`, length must be less than or equal to `8`")  # noqa: E501
        if value is not None and len(value) < 1:
            raise ValueError("Invalid value for `oktmo`, length must be greater than or equal to `1`")  # noqa: E501
        if value is not None and not re.search(r'^(\d{8})|(0)$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `oktmo`, must be a follow pattern or equal to `/(\d{8})|(0)/`")  # noqa: E501
        self.__oktmo = value

    @property
    def payment_period(self):
        """Возвращает payment_period модели PaymentOrderUtilities.

        :return: payment_period модели PaymentOrderUtilities.
        :rtype: PaymentPeriod
        """
        return self.__payment_period

    @payment_period.setter
    def payment_period(self, value):
        """Устанавливает payment_period модели PaymentOrderUtilities.

        :param value: payment_period модели PaymentOrderUtilities.
        :type value: PaymentPeriod
        """
        if isinstance(value, dict):
            self.__payment_period = PaymentPeriod(value)
        elif isinstance(value, PaymentPeriod):
            self.__payment_period = value
        else:
            raise TypeError('Invalid payment_period data type in PaymentOrderUtilities.payment_period')

    @property
    def payment_document_id(self):
        """Возвращает payment_document_id модели PaymentOrderUtilities.

        :return: payment_document_id модели PaymentOrderUtilities.
        :rtype: str
        """
        return self.__payment_document_id

    @payment_document_id.setter
    def payment_document_id(self, value):
        """Устанавливает payment_document_id модели PaymentOrderUtilities.

        :param value: payment_document_id модели PaymentOrderUtilities.
        :type value: str
        """
        if value is not None and len(value) > 18:
            raise ValueError("Invalid value for `payment_document_id`, length must be less than or equal to `18`")  # noqa: E501
        if value is not None and len(value) < 18:
            raise ValueError("Invalid value for `payment_document_id`, length must be greater than or equal to `18`")  # noqa: E501
        self.__payment_document_id = value

    @property
    def payment_document_number(self):
        """Возвращает payment_document_number модели PaymentOrderUtilities.

        :return: payment_document_number модели PaymentOrderUtilities.
        :rtype: str
        """
        return self.__payment_document_number

    @payment_document_number.setter
    def payment_document_number(self, value):
        """Устанавливает payment_document_number модели PaymentOrderUtilities.

        :param value: payment_document_number модели PaymentOrderUtilities.
        :type value: str
        """
        if value is not None and len(value) > 30:
            raise ValueError("Invalid value for `payment_document_number`, length must be less than or equal to `30`")  # noqa: E501
        if value is not None and len(value) < 1:
            raise ValueError("Invalid value for `payment_document_number`, length must be greater than or equal to `1`")  # noqa: E501
        if value is not None and not re.search(r'^(.*)([0-9а-яА-Яa-zA-Z]+)(.*)$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `payment_document_number`, must be a follow pattern or equal to `/(.*)([0-9а-яА-Яa-zA-Z]+)(.*)/`")  # noqa: E501
        self.__payment_document_number = value

    @property
    def account_number(self):
        """Возвращает account_number модели PaymentOrderUtilities.

        :return: account_number модели PaymentOrderUtilities.
        :rtype: str
        """
        return self.__account_number

    @account_number.setter
    def account_number(self, value):
        """Устанавливает account_number модели PaymentOrderUtilities.

        :param value: account_number модели PaymentOrderUtilities.
        :type value: str
        """
        if value is not None and len(value) > 30:
            raise ValueError("Invalid value for `account_number`, length must be less than or equal to `30`")  # noqa: E501
        if value is not None and len(value) < 1:
            raise ValueError("Invalid value for `account_number`, length must be greater than or equal to `1`")  # noqa: E501
        if value is not None and not re.search(r'^(.*)([0-9а-яА-Яa-zA-Z]+)(.*)$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `account_number`, must be a follow pattern or equal to `/(.*)([0-9а-яА-Яa-zA-Z]+)(.*)/`")  # noqa: E501
        self.__account_number = value

    @property
    def unified_account_number(self):
        """Возвращает unified_account_number модели PaymentOrderUtilities.

        :return: unified_account_number модели PaymentOrderUtilities.
        :rtype: str
        """
        return self.__unified_account_number

    @unified_account_number.setter
    def unified_account_number(self, value):
        """Устанавливает unified_account_number модели PaymentOrderUtilities.

        :param value: unified_account_number модели PaymentOrderUtilities.
        :type value: str
        """
        if value is not None and len(value) > 10:
            raise ValueError("Invalid value for `unified_account_number`, length must be less than or equal to `10`")  # noqa: E501
        if value is not None and len(value) < 10:
            raise ValueError("Invalid value for `unified_account_number`, length must be greater than or equal to `10`")  # noqa: E501
        self.__unified_account_number = value

    @property
    def service_id(self):
        """Возвращает service_id модели PaymentOrderUtilities.

        :return: service_id модели PaymentOrderUtilities.
        :rtype: str
        """
        return self.__service_id

    @service_id.setter
    def service_id(self, value):
        """Устанавливает service_id модели PaymentOrderUtilities.

        :param value: service_id модели PaymentOrderUtilities.
        :type value: str
        """
        if value is not None and len(value) > 13:
            raise ValueError("Invalid value for `service_id`, length must be less than or equal to `13`")  # noqa: E501
        if value is not None and len(value) < 13:
            raise ValueError("Invalid value for `service_id`, length must be greater than or equal to `13`")  # noqa: E501
        self.__service_id = value





# coding: utf-8

from yookassa.domain.common import BaseObject
from yookassa.domain.models.invoice import DeliveryMethodType
from yookassa.domain.models.invoice_data.delivery_method import DeliveryMethod


class DeliveryMethodSelf(DeliveryMethod):
    """Данные для самостоятельной доставки пользователю ссылки на счет."""  # noqa: E501

    __url = None
    """URL страницы счета, который необходимо передать пользователю для оплаты. Не более 2048 символов. """  # noqa: E501

    def __init__(self, *args, **kwargs):
        super(DeliveryMethodSelf, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not DeliveryMethodType.SELF:
            self.type = DeliveryMethodType.SELF

    @property
    def url(self):
        """Возвращает url модели DeliveryMethodSelf.

        :return: url модели DeliveryMethodSelf.
        :rtype: str
        """
        return self.__url

    @url.setter
    def url(self, value):
        """Устанавливает url модели DeliveryMethodSelf.

        :param value: url модели DeliveryMethodSelf.
        :type value: str
        """
        self.__url = value




# -*- coding: utf-8 -*-
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.models.payment_data.statement import StatementType
from yookassa.domain.models.payment_data.statement.request.statement_payment_overview import StatementPaymentOverview


class StatementClassMap(DataContext):
    """
    Сопоставление классов Statement по типу.
    """  # noqa: E501

    def __init__(self):
        super(StatementClassMap, self).__init__('request')

    @property
    def request(self):
        return {
            StatementType.PAYMENT_OVERVIEW: StatementPaymentOverview,
        }



# -*- coding: utf-8 -*-
import re
from decimal import Decimal

from yookassa.domain.common import BaseObject
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.receipt_data.industry_details import IndustryDetails
from yookassa.domain.models.receipt_data.mark_code_info import MarkCodeInfo
from yookassa.domain.models.receipt_data.mark_quantity import MarkQuantity


class ReceiptItem(BaseObject):
    """
    Информация о товарной позиции в заказе. Используется для формирования чека.
    """  # noqa: E501

    __description = None
    """Название товара (не более 128 символов). Тег в 54 ФЗ — 1030)."""  # noqa: E501

    __amount = None
    """Суммарная стоимость покупаемого товара в копейках/центах."""  # noqa: E501

    __vat_code = None
    """Ставка НДС, число 1-10 (тег в 54 ФЗ — 1199). Перечень возможных значений:  * %[для Чеков от ЮKassa](/developers/payment-acceptance/receipts/54fz/yoomoney/parameters-values#vat-codes) * %[для сторонних онлайн-касс](/developers/payment-acceptance/receipts/54fz/other-services/parameters-values#vat-codes) """  # noqa: E501

    __quantity = None
    """Количество товара (тег в 54 ФЗ — 1023). Формат: десятичное число, дробная часть — три знака или больше (количество знаков зависит от `quantity` в запросе). Разделитель дробной части — точка, разделитель тысяч отсутствует. Пример: ~`5.000` """  # noqa: E501

    __measure = None
    """Мера количества предмета расчета (тег в 54 ФЗ — 2108)."""  # noqa: E501

    __mark_quantity = None
    """Дробное количество маркированного товара (тег в 54 ФЗ — 1291)."""  # noqa: E501

    __payment_subject = None
    """Признак предмета расчета (тег в 54 ФЗ — 1212)."""  # noqa: E501

    __payment_mode = None
    """Признак способа расчета (тег в 54 ФЗ — 1214)."""  # noqa: E501

    __country_of_origin_code = None
    """Код страны происхождения товара по общероссийскому классификатору стран мира ([OК (MК (ИСО 3166) 004-97) 025-2001](http://docs.cntd.ru/document/842501280)). Тег в 54 ФЗ — 1230. Пример: ~`RU`. <br/>Онлайн-кассы, которые поддерживают этот параметр: Orange Data, Кит Инвест. """  # noqa: E501

    __customs_declaration_number = None
    """Номер таможенной декларации (от 1 до 32 символов). Тег в 54 ФЗ — 1231. <br/>Онлайн-кассы, которые поддерживают этот параметр: Orange Data, Кит Инвест. """  # noqa: E501

    __excise = None
    """Сумма акциза товара с учетом копеек (тег в 54 ФЗ — 1229). Десятичное число с точностью до 2 символов после точки. <br/>Онлайн-кассы, которые поддерживают этот параметр: Orange Data, Кит Инвест. """  # noqa: E501

    __product_code = None
    """Код товара — уникальный номер, который присваивается экземпляру товара при [маркировке](http://docs.cntd.ru/document/902192509) (тег в 54 ФЗ — 1162). <br/>Формат: число в шестнадцатеричном представлении с пробелами. Максимальная длина — 32 байта. Пример: ~`00 00 00 01 00 21 FA 41 00 23 05 41 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 12 00 AB 00`. <br/>Обязательный параметр, если товар нужно [маркировать](http://docs.cntd.ru/document/557297080). """  # noqa: E501

    __planned_status = None
    """Планируемый статус товара. Тег в 54 ФЗ — 2003. Указывается только для товаров, которые подлежат обязательной маркировке (в `items.mark_code_info` передается параметр `gs_1m`, `short` или `fur`).  Перечень возможных значений:  * [для Чеков от ЮKassa](/developers/payment-acceptance/receipts/54fz/yoomoney/parameters-values#planned-status) * [для сторонних онлайн-касс](/developers/payment-acceptance/receipts/54fz/other-services/parameters-values#planned-status) """  # noqa: E501

    __mark_code_info = None
    """Код товара (тег в 54 ФЗ — 1163)."""  # noqa: E501

    __mark_mode = None
    """Режим обработки кода маркировки (тег в 54 ФЗ — 2102).  Обязательный параметр, если одновременно выполняются эти условия:  * вы используете Чеки от ЮKassa или онлайн-кассу Атол Онлайн или BusinessRu, обновленную до ФФД 1.2; * товар нужно [маркировать](http://docs.cntd.ru/document/902192509).  Должен принимать значение равное «0». """  # noqa: E501

    __payment_subject_industry_details = None
    """Отраслевой реквизит предмета расчета  (тег в 54 ФЗ — 1260). Обязателен при использовании ФФД 1.2."""  # noqa: E501

    @property
    def description(self):
        """
        Возвращает description модели ReceiptItem.

        :return: description модели ReceiptItem.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели ReceiptItem.

        :param value: description модели ReceiptItem.
        :type value: str
        """
        self.__description = str(value)

    @property
    def amount(self):
        """
        Возвращает amount модели ReceiptItem.

        :return: amount модели ReceiptItem.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели ReceiptItem.

        :param value: amount модели ReceiptItem.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def vat_code(self):
        """
        Возвращает vat_code модели ReceiptItem.

        :return: vat_code модели ReceiptItem.
        :rtype: int
        """
        return self.__vat_code

    @vat_code.setter
    def vat_code(self, value):
        """
        Устанавливает vat_code модели ReceiptItem.

        :param value: vat_code модели ReceiptItem.
        :type value: int
        """
        self.__vat_code = int(value)

    @property
    def quantity(self):
        """
        Возвращает quantity модели ReceiptItem.

        :return: quantity модели ReceiptItem.
        :rtype: Decimal
        """
        return self.__quantity

    @quantity.setter
    def quantity(self, value):
        """
        Устанавливает quantity модели ReceiptItem.

        :param value: quantity модели ReceiptItem.
        :type value: Decimal
        """
        self.__quantity = Decimal(str(float(value)))

    @property
    def measure(self):
        """
        Возвращает measure модели ReceiptItem.

        :return: measure модели ReceiptItem.
        :rtype: str
        """
        return self.__measure

    @measure.setter
    def measure(self, value):
        """
        Устанавливает measure модели ReceiptItem.

        :param value: measure модели ReceiptItem.
        :type value: str
        """
        self.__measure = value

    @property
    def mark_quantity(self):
        """
        Возвращает mark_quantity модели ReceiptItem.

        :return: mark_quantity модели ReceiptItem.
        :rtype: MarkQuantity
        """
        return self.__mark_quantity

    @mark_quantity.setter
    def mark_quantity(self, value):
        """
        Устанавливает mark_quantity модели ReceiptItem.

        :param value: mark_quantity модели ReceiptItem.
        :type value: MarkQuantity
        """
        if isinstance(value, dict):
            self.__mark_quantity = MarkQuantity(value)
        elif isinstance(value, MarkQuantity):
            self.__mark_quantity = value
        else:
            raise TypeError('Invalid mark_quantity data type in ReceiptItem.mark_quantity')

    @property
    def payment_subject(self):
        """
        Возвращает payment_subject модели ReceiptItem.

        :return: payment_subject модели ReceiptItem.
        :rtype: str
        """
        return self.__payment_subject

    @payment_subject.setter
    def payment_subject(self, value):
        """
        Устанавливает payment_subject модели ReceiptItem.

        :param value: payment_subject модели ReceiptItem.
        :type value: str
        """
        self.__payment_subject = str(value)

    @property
    def payment_mode(self):
        """
        Возвращает payment_mode модели ReceiptItem.

        :return: payment_mode модели ReceiptItem.
        :rtype: str
        """
        return self.__payment_mode

    @payment_mode.setter
    def payment_mode(self, value):
        """
        Устанавливает payment_mode модели ReceiptItem.

        :param value: payment_mode модели ReceiptItem.
        :type value: str
        """
        self.__payment_mode = str(value)

    @property
    def country_of_origin_code(self):
        """
        Возвращает country_of_origin_code модели ReceiptItem.

        :return: country_of_origin_code модели ReceiptItem.
        :rtype: str
        """
        return self.__country_of_origin_code

    @country_of_origin_code.setter
    def country_of_origin_code(self, value):
        """
        Устанавливает country_of_origin_code модели ReceiptItem.

        :param value: country_of_origin_code модели ReceiptItem.
        :type value: str
        """
        self.__country_of_origin_code = str(value)

    @property
    def customs_declaration_number(self):
        """
        Возвращает customs_declaration_number модели ReceiptItem.

        :return: customs_declaration_number модели ReceiptItem.
        :rtype: str
        """
        return self.__customs_declaration_number

    @customs_declaration_number.setter
    def customs_declaration_number(self, value):
        """
        Устанавливает customs_declaration_number модели ReceiptItem.

        :param value: customs_declaration_number модели ReceiptItem.
        :type value: str
        """
        self.__customs_declaration_number = str(value)

    @property
    def excise(self):
        """
        Возвращает excise модели ReceiptItem.

        :return: excise модели ReceiptItem.
        :rtype: str
        """
        return self.__excise

    @excise.setter
    def excise(self, value):
        """
        Устанавливает excise модели ReceiptItem.

        :param value: excise модели ReceiptItem.
        :type value: str
        """
        self.__excise = Decimal(str(value))

    @property
    def product_code(self):
        """
        Возвращает product_code модели ReceiptItem.

        :return: product_code модели ReceiptItem.
        :rtype: str
        """
        return self.__product_code

    @product_code.setter
    def product_code(self, value):
        """
        Устанавливает product_code модели ReceiptItem.

        :param value: product_code модели ReceiptItem.
        :type value: str
        """
        self.__product_code = str(value)

    @property
    def planned_status(self):
        """Возвращает planned_status модели ReceiptItem.

        :return: planned_status модели ReceiptItem.
        :rtype: int
        """
        return self.__planned_status

    @planned_status.setter
    def planned_status(self, value):
        """Устанавливает planned_status модели ReceiptItem.

        :param value: planned_status модели ReceiptItem.
        :type value: int
        """
        self.__planned_status = int(value)

    @property
    def mark_code_info(self):
        """
        Возвращает mark_code_info модели ReceiptItem.

        :return: mark_code_info модели ReceiptItem.
        :rtype: MarkCodeInfo
        """
        return self.__mark_code_info

    @mark_code_info.setter
    def mark_code_info(self, value):
        """
        Устанавливает mark_code_info модели ReceiptItem.

        :param value: mark_code_info модели ReceiptItem.
        :type value: MarkCodeInfo
        """
        if isinstance(value, dict):
            self.__mark_code_info = MarkCodeInfo(value)
        elif isinstance(value, MarkCodeInfo):
            self.__mark_code_info = value
        else:
            raise TypeError('Invalid mark_code_info data type in ReceiptItem.mark_code_info')

    @property
    def mark_mode(self):
        """
        Возвращает mark_mode модели ReceiptItem.

        :return: mark_mode модели ReceiptItem.
        :rtype: str
        """
        return self.__mark_mode

    @mark_mode.setter
    def mark_mode(self, value):
        """
        Устанавливает mark_mode модели ReceiptItem.

        :param value: mark_mode модели ReceiptItem.
        :type value: str
        """
        if value is not None and not re.search(r'^[0]{1}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `mark_mode`, must be a follow pattern or equal to `/^[0]{1}$/`")  # noqa: E501
        self.__mark_mode = value

    @property
    def payment_subject_industry_details(self):
        """
        Возвращает payment_subject_industry_details модели ReceiptItem.

        :return: payment_subject_industry_details модели ReceiptItem.
        :rtype: list[IndustryDetails]
        """
        return self.__payment_subject_industry_details

    @payment_subject_industry_details.setter
    def payment_subject_industry_details(self, value):
        """
        Устанавливает payment_subject_industry_details модели ReceiptItem.

        :param value: payment_subject_industry_details модели ReceiptItem.
        :type value: list[IndustryDetails]
        """
        if isinstance(value, list):
            items = []
            for item in value:
                if isinstance(item, dict):
                    items.append(IndustryDetails(item))
                elif isinstance(item, IndustryDetails):
                    items.append(item)
                else:
                    raise TypeError(
                        'Invalid payment_subject_industry_details data type in ReceiptItem.payment_subject_industry_details')
            self.__payment_subject_industry_details = items
        else:
            raise TypeError('Invalid payment_subject_industry_details value type in ReceiptItem')


class PaymentMode(object):
    """
    Признак способа расчета (тег в 54 ФЗ — 1214) — отражает тип оплаты и факт передачи товара. Пример: покупатель полностью оплачивает товар и сразу получает его. В этом случае нужно передать значение ~`full_payment` (полный расчет).
    Перечень возможных значений:
        * для Чеков от ЮKassa(/developers/payment-acceptance/receipts/54fz/yoomoney/parameters-values#payment-mode)
        * для сторонних онлайн-касс(/developers/payment-acceptance/receipts/54fz/other-services/parameters-values#payment-mode)
    """  # noqa: E501

    """
    Список допустимых значений
    """
    FULL_PREPAYMENT = 'full_prepayment'
    """Полная предоплата."""
    PARTIAL_PREPAYMENT = 'partial_prepayment'
    """Частичная предоплата."""
    ADVANCE = 'advance'
    """Аванс."""
    FULL_PAYMENT = 'full_payment'
    """Полный расчет."""
    PARTIAL_PAYMENT = 'partial_payment'
    """Частичный расчет и кредит."""
    CREDIT = 'credit'
    """Кредит."""
    CREDIT_PAYMENT = 'credit_payment'
    """Выплата по кредиту."""


class PaymentSubject(object):
    """
    Признак предмета расчета (тег в 54 ФЗ — 1212) — это то, за что принимается оплата, например товар, услуга.
    Перечень возможных значений:
        * для Чеков от ЮKassa(/developers/payment-acceptance/receipts/54fz/yoomoney/parameters-values#payment-subject)
        * для сторонних онлайн-касс(/developers/payment-acceptance/receipts/54fz/other-services/parameters-values#payment-subject)
    """  # noqa: E501

    """
    Список допустимых значений
    """
    COMMODITY = 'commodity'
    """Товар."""
    EXCISE = 'excise'
    """Подакцизный товар."""
    JOB = 'job'
    """Работа."""
    SERVICE = 'service'
    """Услуга."""
    GAMBLING_BET = 'gambling_bet'
    """Ставка в азартной игре."""
    GAMBLING_PRIZE = 'gambling_prize'
    """Выигрыш азартной игры."""
    LOTTERY = 'lottery'
    """Лотерейный билет."""
    LOTTERY_PRIZE = 'lottery_prize'
    """Выигрыш в лотерею."""
    INTELLECTUAL_ACTIVITY = 'intellectual_activity'
    """Результаты интеллектуальной деятельности."""
    PAYMENT = 'payment'
    """Платеж."""
    AGENT_COMMISSION = 'agent_commission'
    """Агентское вознаграждение."""
    COMPOSITE = 'composite'
    """Несколько вариантов."""
    ANOTHER = 'another'
    """Другое."""


class ReceiptItemMeasure(object):
    """
    Мера количества предмета расчета (тег в 54 ФЗ — 2108) — единица измерения товара, например штуки, граммы.
    Обязательный параметр, если используете Чеки от ЮKassa или онлайн-кассу, обновленную до ФФД 1.2.
    Перечень возможных значений:
        * для Чеков от ЮKassa(/developers/payment-acceptance/receipts/54fz/yoomoney/parameters-values#measure)
        * для сторонних онлайн-касс(/developers/payment-acceptance/receipts/54fz/other-services/parameters-values#measure)
    """  # noqa: E501

    """
    Список допустимых значений
    """
    PIECE = 'piece'
    """Штука, единица товара."""
    GRAM = 'gram'
    """Грамм."""
    KILOGRAM = 'kilogram'
    """Килограмм."""
    TON = 'ton'
    """Тонна."""
    CENTIMETER = 'centimeter'
    """Сантиметр."""
    DECIMETER = 'decimeter'
    """Дециметр."""
    METER = 'meter'
    """Метр."""
    SQUARE_CENTIMETER = 'square_centimeter'
    """Квадратный сантиметр."""
    SQUARE_DECIMETER = 'square_decimeter'
    """Квадратный дециметр."""
    SQUARE_METER = 'square_meter'
    """Квадратный метр."""
    MILLILITER = 'milliliter'
    """Миллилитр."""
    LITER = 'liter'
    """Литр."""
    CUBIC_METER = 'cubic_meter'
    """Кубический метр."""
    KILOWATT_HOUR = 'kilowatt_hour'
    """Килловат-час."""
    GIGACALORIE = 'gigacalorie'
    """Гигакалория."""
    DAY = 'day'
    """Сутки."""
    HOUR = 'hour'
    """Час."""
    MINUTE = 'minute'
    """Минута."""
    SECOND = 'second'
    """Секунда."""
    KILOBYTE = 'kilobyte'
    """Килобайт."""
    MEGABYTE = 'megabyte'
    """Мегабайт."""
    GIGABYTE = 'gigabyte'
    """Гигабайт."""
    TERABYTE = 'terabyte'
    """Терабайт."""
    ANOTHER = 'another'
    """Другое."""



# -*- coding: utf-8 -*-
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.models.payment_data.payment_order.payment_order_type import PaymentOrderType
from yookassa.domain.models.payment_data.payment_order.request.payment_order_utilities import PaymentOrderUtilities


class PaymentOrderClassMap(DataContext):
    """
    Сопоставление классов PaymentOrder по типу.
    """  # noqa: E501

    def __init__(self):
        super(PaymentOrderClassMap, self).__init__('request')

    @property
    def request(self):
        return {
            PaymentOrderType.UTILITIES: PaymentOrderUtilities,
        }



# coding: utf-8

from yookassa.domain.common import BaseObject


class PaymentInvoiceDetails(BaseObject):
    """Данные о выставленном счете, в рамках которого проведен платеж."""  # noqa: E501

    __id = None
    """Идентификатор счета в ЮКасса."""  # noqa: E501

    @property
    def id(self):
        """Возвращает id модели PaymentInvoiceDetails.

        :return: id модели PaymentInvoiceDetails.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """Устанавливает id модели PaymentInvoiceDetails.

        :param value: id модели PaymentInvoiceDetails.
        :type value: str
        """
        self.__id = value



# -*- coding: utf-8 -*-
from yookassa.domain.common.confirmation_type import ConfirmationType
from yookassa.domain.common.data_context import DataContext
from yookassa.domain.models.payment_method.request.payment_method_confirmation_redirect import \
    PaymentMethodConfirmationRedirect as RequestPaymentMethodConfirmationRedirect
from yookassa.domain.models.payment_method.response.payment_method_confirmation_redirect import \
    PaymentMethodConfirmationRedirect as ResponsePaymentMethodConfirmationRedirect


class PaymentMethodConfirmationClassMap(DataContext):
    """
    Сопоставление классов PaymentMethodConfirmation по типу.
    """  # noqa: E501

    def __init__(self):
        super(PaymentMethodConfirmationClassMap, self).__init__(('request', 'response'))

    @property
    def request(self):
        return {
            ConfirmationType.REDIRECT: RequestPaymentMethodConfirmationRedirect,
        }

    @property
    def response(self):
        return {
            ConfirmationType.REDIRECT: ResponsePaymentMethodConfirmationRedirect,
        }



# coding: utf-8
import datetime
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class RefundAuthorizationDetails(BaseObject):
    """Данные об авторизации возврата. Присутствуют только для возвратов платежей, совершенных этими способами оплаты: банковская карта, Mir Pay. """  # noqa: E501

    __rrn = None
    """Retrieval Reference Number — идентификатор банковской транзакции. """  # noqa: E501

    @property
    def rrn(self):
        """Возвращает rrn модели RefundAuthorizationDetails.

        :return: rrn модели RefundAuthorizationDetails.
        :rtype: str
        """
        return self.__rrn

    @rrn.setter
    def rrn(self, value):
        """Устанавливает rrn модели RefundAuthorizationDetails.

        :param value: rrn модели RefundAuthorizationDetails.
        :type value: str
        """
        self.__rrn = value





# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import ResponseObject
from yookassa.domain.models.self_employed_data.confirmation_factory import SelfEmployedConfirmationFactory


class SelfEmployedResponse(ResponseObject):
    """
    Объект ответа, возвращаемого API при запросе информации о самозанятом.
    """  # noqa: E501

    __id = None
    """Идентификатор самозанятого в ЮKassa."""  # noqa: E501

    __status = None
    """Статус подключения самозанятого и выдачи ЮMoney прав на регистрацию чеков."""  # noqa: E501

    __created_at = None
    """Время создания объекта самозанятого. Указывается по [UTC](https://ru.wikipedia.org/wiki/Всемирное_координированное_время) и передается в формате [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601). Пример: ~`2017-11-03T11:52:31.827Z` """  # noqa: E501

    __itn = None
    """ИНН самозанятого."""  # noqa: E501

    __phone = None
    """Телефон самозанятого, который привязан к личному кабинету в сервисе Мой налог."""  # noqa: E501

    __confirmation = None
    """Сценарий подтверждения пользователем заявки ЮMoney на получение прав для регистрации чеков в сервисе Мой налог."""  # noqa: E501

    __description = None
    """Описание к созданию самозанятого."""

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    __test = None
    """Признак тестовой операции."""  # noqa: E501

    @property
    def id(self):
        """
        Возвращает id модели SelfEmployedResponse.

        :return: id модели SelfEmployedResponse.
        :rtype: str
        """
        return self.__id

    @id.setter
    def id(self, value):
        """
        Устанавливает id модели SelfEmployedResponse.

        :param value: id модели SelfEmployedResponse.
        :type value: str
        """
        self.__id = value

    @property
    def status(self):
        """
        Возвращает status модели SelfEmployedResponse.

        :return: status модели SelfEmployedResponse.
        :rtype: str
        """
        return self.__status

    @status.setter
    def status(self, value):
        """
        Устанавливает status модели SelfEmployedResponse.

        :param value: status модели SelfEmployedResponse.
        :type value: str
        """
        self.__status = str(value)

    @property
    def created_at(self):
        """
        Возвращает created_at модели SelfEmployedResponse.

        :return: created_at модели SelfEmployedResponse.
        :rtype: datetime
        """
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        """
        Устанавливает created_at модели SelfEmployedResponse.

        :param value: created_at модели SelfEmployedResponse.
        :type value: datetime
        """
        self.__created_at = value

    @property
    def itn(self):
        """
        Возвращает itn модели SelfEmployedResponse.

        :return: itn модели SelfEmployedResponse.
        :rtype: str
        """
        return self.__itn

    @itn.setter
    def itn(self, value):
        """
        Устанавливает itn модели SelfEmployedResponse.

        :param value: itn модели SelfEmployedResponse.
        :type value: str
        """
        self.__itn = value

    @property
    def phone(self):
        """
        Возвращает phone модели SelfEmployedResponse.

        :return: phone модели SelfEmployedResponse.
        :rtype: str
        """
        return self.__phone

    @phone.setter
    def phone(self, value):
        """
        Устанавливает phone модели SelfEmployedResponse.

        :param value: phone модели SelfEmployedResponse.
        :type value: str
        """
        self.__phone = str(value)

    @property
    def confirmation(self):
        """
        Возвращает confirmation модели SelfEmployedResponse.

        :return: confirmation модели SelfEmployedResponse.
        :rtype: SelfEmployedConfirmation
        """
        return self.__confirmation

    @confirmation.setter
    def confirmation(self, value):
        """
        Устанавливает confirmation модели SelfEmployedResponse.

        :param value: confirmation модели SelfEmployedResponse.
        :type value: SelfEmployedConfirmation
        """
        self.__confirmation = SelfEmployedConfirmationFactory().create(value, self.context())

    @property
    def description(self):
        """
        Возвращает description модели SelfEmployedResponse.

        :return: description модели SelfEmployedResponse.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели SelfEmployedResponse.

        :param value: description модели SelfEmployedResponse.
        :type value: str
        """
        self.__description = value

    @property
    def metadata(self):
        """
        Возвращает metadata модели SelfEmployedResponse.

        :return: metadata модели SelfEmployedResponse.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели SelfEmployedResponse.

        :param value: metadata модели SelfEmployedResponse.
        :type value: dict[str, str]
        """
        self.__metadata = value

    @property
    def test(self):
        """
        Возвращает test модели SelfEmployedResponse.

        :return: test модели SelfEmployedResponse.
        :rtype: bool
        """
        return self.__test

    @test.setter
    def test(self, value):
        """
        Устанавливает test модели SelfEmployedResponse.

        :param value: test модели SelfEmployedResponse.
        :type value: bool
        """
        self.__test = value



# -*- coding: utf-8 -*-
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.models.payment_method.payment_method_confirmation_class_map import \
    PaymentMethodConfirmationClassMap


class PaymentMethodConfirmationFactory(TypeFactory):
    """
    Фабрика создания объекта PaymentMethodConfirmation по типу.
    """  # noqa: E501

    def __init__(self):
        super(PaymentMethodConfirmationFactory, self).__init__(PaymentMethodConfirmationClassMap())



# -*- coding: utf-8 -*-
from yookassa.domain.request.payment_request import PaymentRequest


class PaymentRequestBuilder(object):
    """
    Конструктор запроса на проведение нового платежа.
    """  # noqa: E501

    def __init__(self):
        self.__request = PaymentRequest()

    def set_recipient(self, value):
        """
        Устанавливает type модели PaymentRequestBuilder.

        :param value: type модели PaymentRequestBuilder.
        :type value: Recipient
        :rtype: PaymentRequestBuilder
        """
        self.__request.recipient = value
        return self

    def set_amount(self, value):
        """
        Устанавливает amount модели PaymentRequestBuilder.

        :param value: amount модели PaymentRequestBuilder.
        :type value: Amount
        :rtype: PaymentRequestBuilder
        """
        self.__request.amount = value
        return self

    def set_description(self, value):
        """
        Устанавливает description модели PaymentRequestBuilder.

        :param value: description модели PaymentRequestBuilder.
        :type value: str
        :rtype: PaymentRequestBuilder
        """
        self.__request.description = value
        return self

    def set_receipt(self, value):
        """
        Устанавливает receipt модели PaymentRequestBuilder.

        :param value: receipt модели PaymentRequestBuilder.
        :type value: Receipt
        :rtype: PaymentRequestBuilder
        """
        self.__request.receipt = value
        return self

    def set_payment_token(self, value):
        """
        Устанавливает payment_token модели PaymentRequestBuilder.

        :param value: payment_token модели PaymentRequestBuilder.
        :type value: str
        :rtype: PaymentRequestBuilder
        """
        self.__request.payment_token = value
        return self

    def set_payment_method_id(self, value):
        """
        Устанавливает payment_method_id модели PaymentRequestBuilder.

        :param value: payment_method_id модели PaymentRequestBuilder.
        :type value: str
        :rtype: PaymentRequestBuilder
        """
        self.__request.payment_method_id = value
        return self

    def set_payment_method_data(self, value):
        """
        Устанавливает payment_method_data модели PaymentRequestBuilder.

        :param value: payment_method_data модели PaymentRequestBuilder.
        :type value: PaymentData
        :rtype: PaymentRequestBuilder
        """
        self.__request.payment_method_data = value
        return self

    def set_confirmation(self, value):
        """
        Устанавливает confirmation модели PaymentRequestBuilder.

        :param value: confirmation модели PaymentRequestBuilder.
        :type value: Confirmation
        :rtype: PaymentRequestBuilder
        """
        self.__request.confirmation = value
        return self

    def set_save_payment_method(self, value):
        """
        Устанавливает save_payment_method модели PaymentRequestBuilder.

        :param value: save_payment_method модели PaymentRequestBuilder.
        :type value: bool
        :rtype: PaymentRequestBuilder
        """
        self.__request.save_payment_method = value
        return self

    def set_capture(self, value):
        """
        Устанавливает capture модели PaymentRequestBuilder.

        :param value: capture модели PaymentRequestBuilder.
        :type value: bool
        :rtype: PaymentRequestBuilder
        """
        self.__request.capture = value
        return self

    def set_client_ip(self, value):
        """
        Устанавливает client_ip модели PaymentRequestBuilder.

        :param value: client_ip модели PaymentRequestBuilder.
        :type value: str
        :rtype: PaymentRequestBuilder
        """
        self.__request.client_ip = value
        return self

    def set_airline(self, value):
        """
        Устанавливает airline модели PaymentRequestBuilder.

        :param value: airline модели PaymentRequestBuilder.
        :type value: Airline
        :rtype: PaymentRequestBuilder
        """
        self.__request.airline = value
        return self

    def set_metadata(self, value):
        """
        Устанавливает metadata модели PaymentRequestBuilder.

        :param value: metadata модели PaymentRequestBuilder.
        :type value: dict[str, str]
        :rtype: PaymentRequestBuilder
        """
        self.__request.metadata = value
        return self

    def set_transfers(self, value):
        """
        Устанавливает transfers модели PaymentRequestBuilder.

        :param value: transfers модели PaymentRequestBuilder.
        :type value: list[Transfer]
        :rtype: PaymentRequestBuilder
        """
        self.__request.transfers = value
        return self

    def set_deal(self, value):
        """
        Устанавливает deal модели PaymentRequestBuilder.

        :param value: deal модели PaymentRequestBuilder.
        :type value: PaymentDealInfo
        :rtype: PaymentRequestBuilder
        """
        self.__request.deal = value
        return self

    def set_fraud_data(self, value):
        """
        Устанавливает fraud_data модели PaymentRequestBuilder.
        Больше не поддерживается. Вместо него нужно использовать `receiver`

        :param value: fraud_data модели PaymentRequestBuilder.
        :type value: FraudData
        :rtype: PaymentRequestBuilder
        """
        self.__request.fraud_data = value
        return self

    def set_merchant_customer_id(self, value):
        """
        Устанавливает merchant_customer_id модели PaymentRequestBuilder.

        :param value: merchant_customer_id модели PaymentRequestBuilder.
        :type value: str
        :rtype: PaymentRequestBuilder
        """
        self.__request.merchant_customer_id = value
        return self

    def receiver(self, value):
        """
        Устанавливает receiver модели PaymentRequestBuilder.

        :param value: receiver модели PaymentRequestBuilder.
        :type value: Receiver
        :rtype: PaymentRequestBuilder
        """
        self.__request.receiver = value
        return self

    def set_payment_order(self, value):
        """
        Устанавливает payment_order модели PaymentRequestBuilder.

        :param value: payment_order модели PaymentRequestBuilder.
        :type value: PaymentOrder
        :rtype: PaymentRequestBuilder
        """
        self.__request.payment_order = value
        return self

    def set_statements(self, value):
        """
        Устанавливает statements модели PaymentRequestBuilder.

        :param value: statements модели PaymentRequestBuilder.
        :type value: list[Statement]
        :rtype: PaymentRequestBuilder
        """
        self.__request.statements = value
        return self

    def build(self):
        """
        Возвращает request модели PaymentRequestBuilder.

        :return: request модели PaymentRequestBuilder.
        :rtype: PaymentRequest
        """
        return self.__request



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject
from yookassa.domain.models import Amount


class ElectronicCertificate(BaseObject):
    """Описание используемого электронного сертификата."""  # noqa: E501

    __certificate_id = None
    """Идентификатор сертификата. От 20 до 30 символов. """  # noqa: E501

    __tru_quantity = None
    """Количество единиц товара, которое одобрили для оплаты по этому электронному сертификату."""  # noqa: E501

    __available_compensation = None
    """
    Максимально допустимая сумма, которую может покрыть электронный сертификат для оплаты одной единицы товара.
    Пример: сертификат может компенсировать максимум 1000 рублей для оплаты этого товара.
    """  # noqa: E501

    __applied_compensation = None
    """
    Сумма, которую одобрили для оплаты по сертификату за одну единицу товара.
    Пример: из 1000 рублей одобрили 500 рублей для оплаты по сертификату.
    """  # noqa: E501

    @property
    def certificate_id(self):
        """Возвращает certificate_id модели ElectronicCertificate.

        :return: certificate_id модели ElectronicCertificate.
        :rtype: str
        """
        return self.__certificate_id

    @certificate_id.setter
    def certificate_id(self, value):
        """Устанавливает certificate_id модели ElectronicCertificate.

        :param value: certificate_id модели ElectronicCertificate.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `certificate_id`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 30:
            raise ValueError("Invalid value for `certificate_id`, length must be less than or equal to `30`")  # noqa: E501
        if value is not None and len(value) < 20:
            raise ValueError("Invalid value for `certificate_id`, length must be greater than or equal to `20`")  # noqa: E501
        self.__certificate_id = value

    @property
    def tru_quantity(self):
        """Возвращает tru_quantity модели ElectronicCertificate.

        :return: tru_quantity модели ElectronicCertificate.
        :rtype: int
        """
        return self.__tru_quantity

    @tru_quantity.setter
    def tru_quantity(self, value):
        """Устанавливает tru_quantity модели ElectronicCertificate.

        :param value: tru_quantity модели ElectronicCertificate.
        :type value: int
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `tru_quantity`, must not be `None`")  # noqa: E501
        self.__tru_quantity = value

    @property
    def available_compensation(self):
        """Возвращает available_compensation модели ElectronicCertificate.

        :return: available_compensation модели ElectronicCertificate.
        :rtype: ElectronicCertificateAvailableCompensation
        """
        return self.__available_compensation

    @available_compensation.setter
    def available_compensation(self, value):
        """Устанавливает available_compensation модели ElectronicCertificate.

        :param value: available_compensation модели ElectronicCertificate.
        :type value: ElectronicCertificateAvailableCompensation
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `available_compensation`, must not be `None`")  # noqa: E501
        if isinstance(value, dict):
            self.__available_compensation = Amount(value)
        elif isinstance(value, Amount):
            self.__available_compensation = value
        else:
            raise TypeError('Invalid available_compensation data type in ElectronicCertificate.available_compensation')

    @property
    def applied_compensation(self):
        """Возвращает applied_compensation модели ElectronicCertificate.

        :return: applied_compensation модели ElectronicCertificate.
        :rtype: ElectronicCertificateAppliedCompensation
        """
        return self.__applied_compensation

    @applied_compensation.setter
    def applied_compensation(self, value):
        """Устанавливает applied_compensation модели ElectronicCertificate.

        :param value: applied_compensation модели ElectronicCertificate.
        :type value: ElectronicCertificateAppliedCompensation
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `applied_compensation`, must not be `None`")  # noqa: E501
        if isinstance(value, dict):
            self.__applied_compensation = Amount(value)
        elif isinstance(value, Amount):
            self.__applied_compensation = value
        else:
            raise TypeError('Invalid applied_compensation data type in ElectronicCertificate.applied_compensation')





# -*- coding: utf-8 -*-
from yookassa.domain.common.request_object import RequestObject
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.deal import PayoutDealInfo
from yookassa.domain.models.payout_data.payout_destination import PayoutDestination
from yookassa.domain.models.payout_data.payout_destination_factory import PayoutDestinationFactory
from yookassa.domain.models.payout_data.request.income_receipt import IncomeReceiptData
from yookassa.domain.models.personal_data import PayoutPersonalData
from yookassa.domain.models.self_employed import PayoutSelfEmployed

DESCRIPTION_MAX_LENGTH = 128


class PayoutRequest(RequestObject):
    """
    Объект запроса к API на проведение новой выплаты.
    """  # noqa: E501

    __amount = None
    """Сумма создаваемой выплаты."""  # noqa: E501

    __payout_destination_data = None
    """Данные платежного средства, на которое нужно сделать выплату. Обязательный параметр, если не передан payout_token."""  # noqa: E501

    __payout_token = None
    """Токенизированные данные для выплаты. Например, синоним банковской карты. Обязательный параметр, если не передан `payout_destination_data` или `payment_method_id`. """  # noqa: E501

    __payment_method_id = None
    """Идентификатор сохраненного способа оплаты, данные которого нужно использовать для проведения выплаты."""  # noqa: E501

    __description = None
    """Описание транзакции (не более 128 символов). Например: «Выплата по договору 37». """  # noqa: E501

    __deal = None
    """Сделка, в рамках которой нужно провести выплату. Необходимо передавать, если вы проводите Безопасную сделку."""  # noqa: E501

    __self_employed = None
    """Данные самозанятого, который получит выплату. Необходимо передавать, если вы делаете выплату [самозанятому](https://yookassa.ru/developers/payouts/scenario-extensions/self-employed). Только для обычных выплат."""  # noqa: E501

    __receipt_data = None
    """Данные для формирования чека в сервисе Мой налог. Необходимо передавать, если вы делаете выплату [самозанятому](https://yookassa.ru/developers/payouts/scenario-extensions/self-employed). Только для обычных выплат."""  # noqa: E501

    __personal_data = None
    """Персональные данные получателя выплаты. Необходимо передавать, если вы делаете выплаты с %[проверкой получателя](/developers/payouts/scenario-extensions/recipient-check) (только для выплат через СБП). """  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    @property
    def amount(self):
        """
        Возвращает amount модели PayoutRequest.

        :return: amount модели PayoutRequest.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели PayoutRequest.

        :param value: amount модели PayoutRequest.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def payout_destination_data(self):
        """
        Возвращает payout_destination_data модели PayoutRequest.

        :return: payout_destination_data модели PayoutRequest.
        :rtype: PayoutDestination
        """
        return self.__payout_destination_data

    @payout_destination_data.setter
    def payout_destination_data(self, value):
        """
        Устанавливает payout_destination_data модели PayoutRequest.

        :param value: payout_destination_data модели PayoutRequest.
        :type value: PayoutDestination
        """
        if isinstance(value, dict):
            self.__payout_destination_data = PayoutDestinationFactory().create(value, self.context())
        elif isinstance(value, PayoutDestination):
            self.__payout_destination_data = value
        else:
            raise TypeError('Invalid payout_destination_data type')

    @property
    def payout_token(self):
        """
        Возвращает payout_token модели PayoutRequest.

        :return: payout_token модели PayoutRequest.
        :rtype: str
        """
        return self.__payout_token

    @payout_token.setter
    def payout_token(self, value):
        """
        Устанавливает payout_token модели PayoutRequest.

        :param value: payout_token модели PayoutRequest.
        :type value: str
        """
        cast_value = str(value)
        if cast_value:
            self.__payout_token = cast_value
        else:
            raise TypeError('Invalid payout_token value')

    @property
    def payment_method_id(self):
        """
        Возвращает payment_method_id модели PayoutRequest.

        :return: payment_method_id модели PayoutRequest.
        :rtype: str
        """
        return self.__payment_method_id

    @payment_method_id.setter
    def payment_method_id(self, value):
        """
        Устанавливает payment_method_id модели PayoutRequest.

        :param value: payment_method_id модели PayoutRequest.
        :type value: str
        """
        self.__payment_method_id = value

    @property
    def description(self):
        """
        Возвращает description модели PayoutRequest.

        :return: description модели PayoutRequest.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели PayoutRequest.

        :param value: description модели PayoutRequest.
        :type value: str
        """
        cast_value = str(value)
        if len(cast_value) <= DESCRIPTION_MAX_LENGTH:
            self.__description = cast_value
        else:
            raise ValueError('The value of the description parameter is too long. Max length is {}'.format(DESCRIPTION_MAX_LENGTH))  # noqa: E501

    @property
    def deal(self):
        """
        Возвращает deal модели PayoutRequest.

        :return: deal модели PayoutRequest.
        :rtype: PayoutDealInfo
        """
        return self.__deal

    @deal.setter
    def deal(self, value):
        """
        Устанавливает deal модели PayoutRequest.

        :param value: deal модели PayoutRequest.
        :type value: PayoutDealInfo
        """
        if isinstance(value, dict):
            self.__deal = PayoutDealInfo(value)
        elif isinstance(value, PayoutDealInfo):
            self.__deal = value
        else:
            raise TypeError('Invalid deal type')

    @property
    def self_employed(self):
        """
        Возвращает self_employed модели PayoutRequest.

        :return: self_employed модели PayoutRequest.
        :rtype: PayoutSelfEmployed
        """
        return self.__self_employed

    @self_employed.setter
    def self_employed(self, value):
        """
        Устанавливает self_employed модели PayoutRequest.

        :param value: self_employed модели PayoutRequest.
        :type value: PayoutSelfEmployed
        """
        if isinstance(value, dict):
            self.__self_employed = PayoutSelfEmployed(value)
        elif isinstance(value, PayoutSelfEmployed):
            self.__self_employed = value
        else:
            raise TypeError('Invalid self_employed data type in PayoutRequest.self_employed')

    @property
    def receipt_data(self):
        """
        Возвращает receipt_data модели PayoutRequest.

        :return: receipt_data модели PayoutRequest.
        :rtype: IncomeReceiptData
        """
        return self.__receipt_data

    @receipt_data.setter
    def receipt_data(self, value):
        """
        Устанавливает receipt_data модели PayoutRequest.

        :param value: receipt_data модели PayoutRequest.
        :type value: IncomeReceiptData
        """
        if isinstance(value, dict):
            self.__receipt_data = IncomeReceiptData(value)
        elif isinstance(value, IncomeReceiptData):
            self.__receipt_data = value
        else:
            raise TypeError('Invalid receipt_data data type in PayoutRequest.receipt_data')

    @property
    def personal_data(self):
        """
        Возвращает personal_data модели PayoutRequest.

        :return: personal_data модели PayoutRequest.
        :rtype: list[PayoutPersonalData]
        """
        return self.__personal_data

    @personal_data.setter
    def personal_data(self, value):
        """
        Устанавливает personal_data модели PayoutRequest.

        :param value: personal_data модели PayoutRequest.
        :type value: list[PayoutPersonalData]
        """
        if isinstance(value, list):
            if len(value) > 2:
                raise ValueError("Invalid value for `personal_data`, number of items must be less than or equal to `2`")  # noqa: E501
            if len(value) < 1:
                raise ValueError("Invalid value for `personal_data`, number of items must be greater than or equal to `1`")  # noqa: E501

            personal_data_array = []
            for personal_dataData in value:
                if isinstance(personal_dataData, dict):
                    personal_data_array.append(PayoutPersonalData(personal_dataData))
                elif isinstance(personal_dataData, PayoutPersonalData):
                    personal_data_array.append(personal_dataData)
                else:
                    raise TypeError('Invalid personal_data data type in PayoutRequest.personal_data')
            self.__personal_data = personal_data_array
        else:
            raise TypeError('Invalid personal_data value type in PayoutRequest')

    @property
    def metadata(self):
        """
        Возвращает metadata модели PayoutRequest.

        :return: metadata модели PayoutRequest.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели PayoutRequest.

        :param value: metadata модели PayoutRequest.
        :type value: dict[str, str]
        """
        if type(value) is dict:
            self.__metadata = value

    def validate(self):
        """
        Влидация данных модели PayoutRequest.
        """
        amount = self.amount
        if amount is None:
            self.__set_validation_error('Payout amount not specified')

        if amount.value <= 0.0:
            self.__set_validation_error('Invalid payout amount value: ' + str(amount.value))

        if (self.payout_token and self.payout_destination_data) or \
                (self.payout_token and self.payment_method_id) or \
                (self.payout_destination_data and self.payment_method_id):
            self.__set_validation_error('Both payout_token, payout_destination_data and payment_method_id values are specified')

        elif self.payout_token is None and self.payout_destination_data is None and self.payment_method_id is None:
            self.__set_validation_error('Both payout_token, payout_destination_data and payment_method_id values are not specified')

    def __set_validation_error(self, message):
        """
        Устанавливает message в Exception при валидации модели PayoutRequest.

        :param message: message модели Exception.
        :type message: str
        """
        raise ValueError(message)



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject
from yookassa.domain.models.amount import Amount


class TransferResponse(BaseObject):
    """
    Объект ответа, возвращаемого API при запросе информации о распределении денег — сколько и в какой магазин нужно перевести.
    """  # noqa: E501

    __account_id = None
    """Идентификатор магазина, в пользу которого вы принимаете оплату."""  # noqa: E501

    __amount = None
    """Сумма, которую необходимо перечислить магазину."""  # noqa: E501

    __status = None
    """Статус распределения денег между магазинами. """  # noqa: E501

    __platform_fee_amount = None
    """Комиссия за проданные товары и услуги, которая удерживается с магазина в вашу пользу."""  # noqa: E501

    __description = None
    """Описание транзакции (не более 128 символов), которое продавец увидит в личном кабинете ЮKassa. Например: «Заказ маркетплейса №72». """  # noqa: E501

    __metadata = None
    """Любые дополнительные данные, которые нужны вам для работы (например, ваш внутренний идентификатор заказа). Передаются в виде набора пар «ключ-значение» и возвращаются в ответе от ЮKassa. Ограничения: максимум 16 ключей, имя ключа не больше 32 символов, значение ключа не больше 512 символов, тип данных — строка в формате UTF-8. """  # noqa: E501

    __release_funds = None
    """Порядок перевода денег продавцам: ~`true` — перевести сразу, ~`false` — сначала захолдировать. """  # noqa: E501

    __connected_account_id = None
    """Идентификатор продавца, подключенного к вашей платформе."""  # noqa: E501

    @property
    def account_id(self):
        """
        Возвращает account_id модели TransferResponse.

        :return: account_id модели TransferResponse.
        :rtype: str
        """
        return self.__account_id

    @account_id.setter
    def account_id(self, value):
        """
        Устанавливает account_id модели TransferResponse.

        :param value: account_id модели TransferResponse.
        :type value: str
        """
        self.__account_id = str(value)

    @property
    def amount(self):
        """
        Возвращает amount модели TransferResponse.

        :return: amount модели TransferResponse.
        :rtype: Amount
        """
        return self.__amount

    @amount.setter
    def amount(self, value):
        """
        Устанавливает amount модели TransferResponse.

        :param value: amount модели TransferResponse.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def status(self):
        """
        Возвращает status модели TransferResponse.

        :return: status модели TransferResponse.
        :rtype: str
        """
        return self.__status

    @status.setter
    def status(self, value):
        """
        Устанавливает status модели TransferResponse.

        :param value: status модели TransferResponse.
        :type value: str
        """
        self.__status = str(value)

    @property
    def platform_fee_amount(self):
        """
        Возвращает platform_fee_amount модели TransferResponse.

        :return: platform_fee_amount модели TransferResponse.
        :rtype: Amount
        """
        return self.__platform_fee_amount

    @platform_fee_amount.setter
    def platform_fee_amount(self, value):
        """
        Устанавливает platform_fee_amount модели TransferResponse.

        :param value: platform_fee_amount модели TransferResponse.
        :type value: Amount
        """
        if isinstance(value, dict):
            self.__platform_fee_amount = Amount(value)
        elif isinstance(value, Amount):
            self.__platform_fee_amount = value
        else:
            raise TypeError('Invalid platform_fee_amount value type')

    @property
    def description(self):
        """
        Возвращает description модели TransferResponse.

        :return: description модели TransferResponse.
        :rtype: str
        """
        return self.__description

    @description.setter
    def description(self, value):
        """
        Устанавливает description модели TransferResponse.

        :param value: description модели TransferResponse.
        :type value: str
        """
        self.__description = str(value)

    @property
    def metadata(self):
        """
        Возвращает metadata модели TransferResponse.

        :return: metadata модели TransferResponse.
        :rtype: dict[str, str]
        """
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        """
        Устанавливает metadata модели TransferResponse.

        :param value: metadata модели TransferResponse.
        :type value: dict[str, str]
        """
        if type(value) is dict:
            self.__metadata = value

    @property
    def release_funds(self):
        """
        Возвращает release_funds модели TransferResponse.

        :return: release_funds модели TransferResponse.
        :rtype: bool
        """
        return self.__release_funds

    @release_funds.setter
    def release_funds(self, value):
        """
        Устанавливает release_funds модели TransferResponse.

        :param value: release_funds модели TransferResponse.
        :type value: bool
        """
        self.__release_funds = value

    @property
    def connected_account_id(self):
        """
        Возвращает connected_account_id модели TransferResponse.

        :return: connected_account_id модели TransferResponse.
        :rtype: str
        """
        return self.__connected_account_id

    @connected_account_id.setter
    def connected_account_id(self, value):
        """
        Устанавливает connected_account_id модели TransferResponse.

        :param value: connected_account_id модели TransferResponse.
        :type value: str
        """
        self.__connected_account_id = value


class TransferStatus(object):
    """
    Статус распределения денег между магазинами. 
    """  # noqa: E501

    """
    Список допустимых значений
    """
    PENDING = 'pending'
    """Ожидает оплаты покупателем."""
    WAITING_FOR_CAPTURE = 'waiting_for_capture'
    """Успешно оплачен покупателем, ожидает подтверждения магазином (capture или aviso)."""
    SUCCEEDED = 'succeeded'
    """Успешно оплачен и получен магазином."""
    CANCELED = 'canceled'
    """Неуспех оплаты или отменен магазином (cancel)."""



# coding: utf-8
import datetime
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class PaymentMethodHolder(BaseObject):
    """Данные магазина, для которого сохраняется способ оплаты."""  # noqa: E501

    __account_id = None
    """Идентификатор магазина в ЮKassa."""  # noqa: E501

    __gateway_id = None
    """Идентификатор субаккаунта. Используется для разделения потоков платежей в рамках одного аккаунта."""  # noqa: E501

    @property
    def account_id(self):
        """Возвращает account_id модели SavePaymentMethodHolder.

        :return: account_id модели SavePaymentMethodHolder.
        :rtype: str
        """
        return self.__account_id

    @account_id.setter
    def account_id(self, value):
        """Устанавливает account_id модели SavePaymentMethodHolder.

        :param value: account_id модели SavePaymentMethodHolder.
        :type value: str
        """
        self.__account_id = value

    @property
    def gateway_id(self):
        """Возвращает gateway_id модели SavePaymentMethodHolder.

        :return: gateway_id модели SavePaymentMethodHolder.
        :rtype: str
        """
        return self.__gateway_id

    @gateway_id.setter
    def gateway_id(self, value):
        """Устанавливает gateway_id модели SavePaymentMethodHolder.

        :param value: gateway_id модели SavePaymentMethodHolder.
        :type value: str
        """
        self.__gateway_id = value



# coding: utf-8

from yookassa.domain.common import BaseObject


class DeliveryMethod(BaseObject):
    """Данные о выбранном способе доставки счета. Присутствует только для счетов в статусе ~`pending`. """  # noqa: E501

    __type = None
    """Код способа доставки счета пользователю"""

    @property
    def type(self):
        """Возвращает type модели DeliveryMethod.

        :return: type модели DeliveryMethod.
        :rtype: str
        """
        return self.__type

    @type.setter
    def type(self, value):
        """Устанавливает type модели DeliveryMethod.

        :param value: type модели DeliveryMethod.
        :type value: str
        """
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self.__type = value


